@@ -60,8 +60,12 @@
 	  (hash-set! cursors "cursor2" (lw6-make-cursor "2"))
 	  (hash-set! cursors "cursor3" (lw6-make-cursor "3"))
 	  (hash-set! cursors "cursor4" (lw6-make-cursor "4"))))
-      (let ((dsp (lw6-get-game-global "dsp")))
-	(if dsp (c-lw6gui-input-reset dsp)))
+      (let (
+	    (dsp (lw6-get-game-global "dsp"))
+	    (snd (lw6-get-game-global "snd"))
+	    )
+	(if dsp (c-lw6gui-input-reset dsp))
+	)
       )))
 
 (define lw6-init-game-globals
@@ -74,13 +78,23 @@
       (lw6-set-game-global! "loaded" (list))
       (lw6-set-game-global! "look" (c-lw6gui-default-look))
       (lw6-set-game-global! "display-param" (lw6-display-param-init))
-      (lw6-set-game-global! "zoom-next-in" (c-lw6sys-timestamp))
-      (lw6-set-game-global! "zoom-next-out" (c-lw6sys-timestamp))
-      (lw6-game-idle)
+      (lw6-set-game-global! "zoom-next-in" (c-lw6sys-get-timestamp))
+      (lw6-set-game-global! "zoom-next-out" (c-lw6sys-get-timestamp))
+      (lw6-game-splash)
       )
     )
   )
 
+(define lw6-game-splash
+  (lambda ()
+    (lw6-game-param-update)
+    (lw6-set-game-global! "command-func" lw6-command-func-idle)
+    (lw6-display-splash-setup)
+    (lw6-set-game-global! "loaded-func" lw6-loaded-func-idle)
+    (lw6-game-reset)
+    )
+  )
+
 (define lw6-game-idle
   (lambda ()
     (lw6-game-param-update)
@@ -110,6 +124,7 @@
     ; we garbage collect before the "realtime" part
     (gc)
     (lw6-play-sound-start)
+    (lw6-music-game (lw6-get-game-global "level"))
     )
   )
 
@@ -182,7 +197,7 @@
 	     (list "1" "2" "3" "4"))
 	(let (
 	      (pilot (c-lw6pil-build-pilot game-state
-					   (c-lw6sys-timestamp)))
+					   (c-lw6sys-get-timestamp)))
 	      )
 	  (begin
 	    (lw6-set-game-global! "pilot" pilot)
@@ -214,7 +229,7 @@
 					      game-state "2" server-id "green"))
 	(let (
 	      (pilot (c-lw6pil-build-pilot game-state
-					   (c-lw6sys-timestamp)))
+					   (c-lw6sys-get-timestamp)))
 	      )
 	  (begin
 	    (lw6-set-game-global! "pilot" pilot)
@@ -243,7 +258,7 @@
 					      game-state "2" server-id "green"))
 	(let (
 	      (pilot (c-lw6pil-build-pilot game-state
-					   (c-lw6sys-timestamp)))
+					   (c-lw6sys-get-timestamp)))
 	      )
 	  (begin
 	    (lw6-set-game-global! "pilot" pilot)
