@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #define TEST_MAP_WIDTH 72
 #define TEST_MAP_HEIGHT 24
 #define TEST_MAP_NB_LAYERS 2
+#define TEST_MAP_NOISE_PERCENT 10
 #define TEST_NB_ROUNDS 1000
 #define TEST_ROUNDS_STEP 10
 #define TEST_SERVER_ID 0x1234123412341234LL
@@ -54,7 +55,8 @@ new_data (lw6map_level_t ** level,
   int ret = 0;
 
   *level =
-    lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT, TEST_MAP_NB_LAYERS);
+    lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			   TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
   *game_struct = lw6ker_game_struct_new (*level, NULL);
   *game_state = lw6ker_game_state_new (*game_struct, NULL);
 
@@ -145,8 +147,18 @@ test_backend (lw6bot_backend_t * backend)
   return ret;
 }
 
+/**
+ * lw6bot_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @bot module test suite. Will try several engines
+ * and query basic moves.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6bot_test ()
+lw6bot_test (int mode)
 {
   int ret = 0;
   int argc = TEST_ARGC;
@@ -159,9 +171,9 @@ lw6bot_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6map_test ();
-      lw6ker_test ();
+      lw6sys_test (mode);
+      lw6map_test (mode);
+      lw6ker_test (mode);
     }
 
   backend[0] = lw6bot_create_backend (argc, argv, "idiot");
