@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -148,7 +148,9 @@ lw6cfg_reset (int argc, char *argv[])
 	      lw6cfg_set_option (cfg_context, LW6DEF_LOG_FILE, value);
 	      LW6SYS_FREE (value);
 	    }
+	  lw6cfg_set_option (cfg_context, LW6DEF_MUSIC_PATH, "");
 	  lw6cfg_set_option (cfg_context, LW6DEF_MAP_PATH, "");
+	  lw6cfg_set_option (cfg_context, LW6DEF_BIN_ID, "0");
 	  lw6cfg_save (cfg_context, config_file);
 	  lw6cfg_quit (cfg_context);
 	}
