@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,6 +32,18 @@
 #include "mod-http/mod-http.h"
 #endif
 
+#ifdef MOD_HTTP
+#define _CLI_DEFAULT_BACKENDS "tcp,udp,http"
+#else
+#define _CLI_DEFAULT_BACKENDS "tcp,udp"
+#endif
+
+char *
+lw6cli_default_backends ()
+{
+  return _CLI_DEFAULT_BACKENDS;
+}
+
 lw6sys_assoc_t *
 lw6cli_get_backends (int argc, char *argv[])
 {
