@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -92,8 +92,17 @@ test_support ()
   return ret;
 }
 
+/**
+ * lw6cns_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @cns module test suite.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6cns_test ()
+lw6cns_test (int mode)
 {
   int ret = 0;
 
@@ -102,7 +111,7 @@ lw6cns_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
+      lw6sys_test (mode);
     }
 
   ret = test_handler () && test_support ();
