@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@
 #define TEST_NB_MENUITEMS2 15
 #define TEST_MENUITEM_LABEL_FORMAT "Item %d"
 #define TEST_MENUITEM_COLORED_INDEX 2
-#define TEST_MAP "strange-new-world/"
+#define TEST_MAP "subflower/"
 #define TEST_NB_ROUNDS 250
 #define TEST_SERVER_ID 0x1234123412341234LL
 #define TEST_CURSOR1_ID 0x1234
@@ -121,7 +121,8 @@ level_new (char *name, int display_width, int display_height,
     {
       ret =
 	lw6ldr_read_relative (map_path, TEST_MAP, NULL, NULL, display_width,
-			      display_height, progress);
+			      display_height, LW6LDR_DEFAULT_BENCH_VALUE,
+			      LW6LDR_DEFAULT_MAGIC_NUMBER, progress);
       LW6SYS_FREE (map_path);
     }
   lw6sys_progress_begin (progress);
@@ -168,7 +169,7 @@ pilot_new (lw6ker_game_state_t * game_state, lw6sys_progress_t * progress)
   lw6pil_pilot_t *ret = NULL;
 
   lw6sys_progress_begin (progress);
-  ret = lw6pil_pilot_new (game_state, lw6sys_timestamp (), progress);
+  ret = lw6pil_pilot_new (game_state, lw6sys_get_timestamp (), progress);
   if (ret)
     {
       // ok
@@ -403,9 +404,9 @@ test_display (char *gfx_backend_name)
 			    _
 			    ("pumping events, try to press random keys while having the focus on the game window, you should get one log message per keypress, test will end after %d seconds"),
 			    (int) (TEST_INPUT_TICKS / LW6SYS_TICKS_PER_SEC));
-		ticks = lw6sys_uptime ();
+		ticks = lw6sys_get_uptime ();
 		while ((!lw6gui_input_poll_quit (display->input))
-		       && lw6sys_uptime () < ticks + TEST_INPUT_TICKS)
+		       && lw6sys_get_uptime () < ticks + TEST_INPUT_TICKS)
 		  {
 		    /*
 		     * Note, there's no sleep in this sloop, should be CPU greedy,
@@ -465,12 +466,15 @@ test_callback_func (void *func_data, char *key, void *value)
 /**
  * lw6dsp_test
  *
- * Runs the test suite for the dsp module.
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the test suite for the dsp module. In check (0) mode, won't
+ * test much to avoid failure because of missing graphical environment.
  *
  * Return value: 1 if OK, 0 if error.
  */
 int
-lw6dsp_test ()
+lw6dsp_test (int mode)
 {
   int ret = 0;
   lw6sys_assoc_t *gfx_backends = NULL;
@@ -482,18 +486,25 @@ lw6dsp_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6cfg_test ();
-      lw6map_test ();
-      lw6ker_test ();
-      lw6gui_test ();
-      lw6gfx_test ();
+      lw6sys_test (mode);
+      lw6cfg_test (mode);
+      lw6map_test (mode);
+      lw6ker_test (mode);
+      lw6gui_test (mode);
+      lw6gfx_test (mode);
     }
 
   gfx_backends = lw6gfx_get_backends (argc, argv);
   if (gfx_backends)
     {
-      lw6sys_assoc_map (gfx_backends, test_callback_func, &ret);
+      if (mode)
+	{
+	  lw6sys_assoc_map (gfx_backends, test_callback_func, &ret);
+	}
+      else
+	{
+	  ret = 1;
+	}
       lw6sys_assoc_free (gfx_backends);
     }
 
