@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,26 +30,31 @@
 #include <SDL/SDL.h>
 #endif
 
-static int ret = 1;
+static int _ret = 1;
+static int _mode = 0;
 
 static void
 run (void *data)
 {
-  ret = lw6dsp_test ();
+  _ret = lw6dsp_test (_mode);
 }
 
 int
 main (int argc, char *argv[])
 {
+  int ret = 0;
+
   LW6SYS_MAIN_BEGIN;
   LW6HLP_MAIN_BEGIN;
 
   lw6sys_log_clear (NULL);
+  _mode = lw6sys_arg_test_mode (argc, argv);
 #ifdef LW6_MAC_OS_X
   lw6sys_vthread_run (run, NULL, NULL);
 #else
   run (NULL);
 #endif
+  ret = _ret;
 
   LW6HLP_MAIN_END;
   LW6SYS_MAIN_END;
