@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -113,6 +113,8 @@ test_path ()
 /**
  * lw6dyn_test
  *
+ * @mode: 0 for check only, 1 for full test
+ *
  * Runs the @dyn module test suite, testing most (if not all...)
  * functions. Will try to load libraries and query them for
  * standard LW6-expected functions.
@@ -120,7 +122,7 @@ test_path ()
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6dyn_test ()
+lw6dyn_test (int mode)
 {
   int ret = 0;
 
@@ -129,7 +131,7 @@ lw6dyn_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
+      lw6sys_test (mode);
     }
 
   ret = test_list () && test_path ();
