@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -43,19 +43,12 @@ typedef struct _mod_gl_background_bubbles_state_s
 }
 _mod_gl_background_bubbles_state_t;
 
-typedef struct _mod_gl_background_bubbles_image_data_s
+typedef struct _mod_gl_background_bubbles_bitmap_data_s
 {
-  SDL_Surface *background;
-  SDL_Surface *bubble;
+  mod_gl_utils_bitmap_t *background;
+  mod_gl_utils_bitmap_t *bubble;
 }
-_mod_gl_background_bubbles_image_data_t;
-
-typedef struct _mod_gl_background_bubbles_texture_data_s
-{
-  GLuint background;
-  GLuint bubble;
-}
-_mod_gl_background_bubbles_texture_data_t;
+_mod_gl_background_bubbles_bitmap_data_t;
 
 typedef struct _mod_gl_background_bubbles_lastest_colors_s
 {
@@ -78,26 +71,12 @@ _mod_gl_background_bubbles_const_data_t;
 typedef struct _mod_gl_background_bubbles_context_s
 {
   _mod_gl_background_bubbles_state_t state;
-  _mod_gl_background_bubbles_image_data_t image_data;
-  _mod_gl_background_bubbles_texture_data_t texture_data;
+  _mod_gl_background_bubbles_bitmap_data_t bitmap_data;
   _mod_gl_background_bubbles_latest_colors_t latest_colors;
   _mod_gl_background_bubbles_const_data_t const_data;
 }
 _mod_gl_background_bubbles_context_t;
 
-// gl-bubbles-colorize.c
-extern int
-_mod_gl_background_bubbles_colorize_if_needed (mod_gl_utils_context_t *
-					       utils_context,
-					       _mod_gl_background_bubbles_context_t
-					       * bubbles_context,
-					       lw6gui_look_t * look);
-extern int _mod_gl_background_bubbles_colorize (mod_gl_utils_context_t *
-						utils_context,
-						_mod_gl_background_bubbles_context_t
-						* bubbles_context,
-						lw6gui_look_t * look);
-
 /*
  * In display.c
  */
