@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 
 #define IMAGE_DIR "hud/floating/image/"
 
-#define IMAGE_MARBLE "marble.jpeg"
+#define IMAGE_GAUGE_FRAME "gauge-frame.png"
 
 static void
 read_callback (void *callback_data, char *element, char *key, char *value)
@@ -50,8 +50,6 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			   &const_data->gauge_slices);
       lw6cfg_read_xml_int (key, value, "gauge-loops",
 			   &const_data->gauge_loops);
-      lw6cfg_read_xml_int (key, value, "gauge-blink-period",
-			   &const_data->gauge_blink_period);
     }
 
   if (!strcmp (element, "float"))
@@ -76,6 +74,12 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			     &const_data->gauge_relative_text_dw);
       lw6cfg_read_xml_float (key, value, "gauge-relative-text-dh",
 			     &const_data->gauge_relative_text_dh);
+      lw6cfg_read_xml_float (key, value, "gauge-relative-percent-only-y1",
+			     &const_data->gauge_relative_percent_only_y1);
+      lw6cfg_read_xml_float (key, value, "gauge-relative-percent-y1",
+			     &const_data->gauge_relative_percent_y1);
+      lw6cfg_read_xml_float (key, value, "gauge-relative-frags-y1",
+			     &const_data->gauge_relative_frags_y1);
       lw6cfg_read_xml_float (key, value, "gauge-start",
 			     &const_data->gauge_start);
       lw6cfg_read_xml_float (key, value, "gauge-sweep",
@@ -130,9 +134,9 @@ load_images (mod_gl_utils_context_t * utils_context,
   lw6sys_log (LW6SYS_LOG_INFO, _("loading images"));
 
   ret =
-    ((floating_context->gauges.image_frame =
-      mod_gl_utils_load_image (utils_context,
-			       IMAGE_DIR IMAGE_MARBLE)) != NULL);
+    ((floating_context->gauges.gauge_frame =
+      mod_gl_utils_bitmap_load (utils_context,
+				IMAGE_DIR IMAGE_GAUGE_FRAME)) != NULL);
   return ret;
 }
 
@@ -143,11 +147,11 @@ static void
 unload_images (mod_gl_utils_context_t * utils_context,
 	       _mod_gl_hud_floating_context_t * floating_context)
 {
-  if (floating_context->gauges.image_frame)
+  if (floating_context->gauges.gauge_frame)
     {
-      mod_gl_utils_unload_image (utils_context,
-				 floating_context->gauges.image_frame);
-      floating_context->gauges.image_frame = NULL;
+      mod_gl_utils_bitmap_free (utils_context,
+				floating_context->gauges.gauge_frame);
+      floating_context->gauges.gauge_frame = NULL;
     }
 }
 
