@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,75 +29,33 @@
 #include "../../mod-gl.h"
 #include "gl-floating-internal.h"
 
-static void
-set_hud_rules (mod_gl_utils_context_t * utils_context)
-{
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
-}
-
 void
 display_clock (mod_gl_utils_context_t * utils_context,
 	       _mod_gl_hud_floating_context_t * floating_context)
 {
-  float x1, x2, y1, y2;
+  float x1, x2, y1, y2, dw, dh;
   float size_factor =
     sqrt (utils_context->video_mode.width * utils_context->video_mode.height);
 
-  if (floating_context->clock.texture_bg)
+  if (floating_context->clock.clock_text
+      && floating_context->clock.clock_text->texture_h > 0)
     {
-      x1 =
-	utils_context->video_mode.width *
-	(floating_context->const_data.clock_x2 +
-	 floating_context->const_data.clock_dw) -
-	size_factor * floating_context->const_data.clock_size *
-	((float) floating_context->clock.texture_w) /
-	((float) floating_context->clock.texture_h);
-      ;
-      y1 =
-	size_factor *
-	(floating_context->const_data.clock_y1 +
-	 floating_context->const_data.clock_dh);
       x2 =
 	utils_context->video_mode.width *
-	(floating_context->const_data.clock_x2 +
-	 floating_context->const_data.clock_dw);
-      y2 =
-	size_factor *
-	(floating_context->const_data.clock_y1 +
-	 floating_context->const_data.clock_dh +
-	 floating_context->const_data.clock_size);
-      mod_gl_utils_display_texture_full (utils_context,
-					 floating_context->clock.texture_bg,
-					 x1, y1, x2, y2,
-					 floating_context->clock.texture_w,
-					 floating_context->clock.texture_h);
-    }
-
-  if (floating_context->clock.texture_fg)
-    {
+	floating_context->const_data.clock_x2;
       x1 =
-	utils_context->video_mode.width *
-	(floating_context->const_data.clock_x2) -
+	x2 -
 	size_factor * floating_context->const_data.clock_size *
-	((float) floating_context->clock.texture_w) /
-	((float) floating_context->clock.texture_h);
+	((float) floating_context->clock.clock_text->texture_w) /
+	((float) floating_context->clock.clock_text->texture_h);
       ;
-      y1 = size_factor * (floating_context->const_data.clock_y1);
-      x2 =
-	utils_context->video_mode.width *
-	(floating_context->const_data.clock_x2);
-      y2 =
-	size_factor *
-	(floating_context->const_data.clock_y1 +
-	 floating_context->const_data.clock_size);
-      mod_gl_utils_display_texture_full (utils_context,
-					 floating_context->clock.texture_fg,
-					 x1, y1, x2, y2,
-					 floating_context->clock.texture_w,
-					 floating_context->clock.texture_h);
+      y1 = size_factor * floating_context->const_data.clock_y1;
+      y2 = y1 + (size_factor * floating_context->const_data.clock_size);
+      dw = size_factor * floating_context->const_data.clock_dw;
+      dh = size_factor * floating_context->const_data.clock_dh;
+      mod_gl_utils_shaded_text_display (utils_context,
+					floating_context->clock.clock_text,
+					x1, y1, x2, y2, dw, dh);
     }
 }
 
@@ -106,35 +64,29 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 		_mod_gl_hud_floating_context_t * floating_context)
 {
   float x1, x2, y1, y2, w, h;
-  float text_x1, text_x2, text_y1, text_y2, text_w, text_h;
+  float text_w, text_h, text_x1, text_x2, text_y1, text_y2, text_dw, text_dh;
   float size_factor_screen =
     sqrt (utils_context->video_mode.width * utils_context->video_mode.height);
   float size_factor_score;
   float size_factor;
   float ratio;
   int percent;
-  int texture_w;
-  int texture_h;
   float inner, outer;
   int slices, loops;
   int i;
   float start;
   float sweep1;
   float sweep2;
-  _mod_gl_hud_floating_gauge_meter_t *gauge_meter = NULL;
-  _mod_gl_hud_floating_gauge_text_t *gauge_text = NULL;
   int team_color;
 
-  if (floating_context->gauges.image_frame)
+  if (floating_context->game_state && floating_context->gauges.gauge_frame
+      && floating_context->gauges.gauge_frame->texture_h > 0)
     {
       x2 = utils_context->video_mode.width;
       y2 = utils_context->video_mode.height;
-      texture_w = floating_context->gauges.image_frame->w;
-      texture_h = floating_context->gauges.image_frame->h;
       start = floating_context->const_data.gauge_start;
       for (i = floating_context->score_array.nb_scores - 1; i >= 0; --i)
 	{
-	  gauge_text = &(floating_context->gauges.gauge_texts[i]);
 	  percent = floating_context->score_array.scores[i].fighters_percent;
 	  ratio = floating_context->score_array.scores[i].fighters_ratio;
 	  /*
@@ -144,8 +96,6 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 	  team_color = floating_context->score_array.scores[i].team_color;
 	  if (team_color >= 0)
 	    {
-	      gauge_meter =
-		&(floating_context->gauges.gauge_meters[team_color]);
 	      size_factor_score =
 		ratio * floating_context->const_data.gauge_max_size + (1.0f -
 								       ratio)
@@ -162,7 +112,9 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 	      sweep1 = ratio * floating_context->const_data.gauge_sweep;
 	      sweep2 = floating_context->const_data.gauge_sweep - sweep1;
 
-	      glDisable (GL_BLEND);
+	      glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	      glEnable (GL_BLEND);
+
 	      glMatrixMode (GL_MODELVIEW);
 	      glPushMatrix ();
 	      glLoadIdentity ();
@@ -176,14 +128,25 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 		size_factor *
 		floating_context->const_data.gauge_relative_bg_outer;
 
-	      if (floating_context->gauges.texture_frame)
+	      if (floating_context->gauges.gauge_frame)
 		{
-		  glBindTexture (GL_TEXTURE_2D,
-				 floating_context->gauges.texture_frame);
-		  gluDisk (floating_context->gauges.disk, inner,
-			   outer, slices, loops);
+		  mod_gl_utils_bitmap_colorize (utils_context,
+						floating_context->gauges.
+						gauge_frame,
+						floating_context->look->style.
+						colorize,
+						&(floating_context->look->
+						  style.color_set.
+						  hud_color_frame));
+		  mod_gl_utils_bitmap_bind (utils_context,
+					    floating_context->gauges.
+					    gauge_frame);
+		  gluDisk (floating_context->gauges.disk, inner, outer,
+			   slices, loops);
 		}
 
+	      glDisable (GL_BLEND);
+
 	      inner =
 		size_factor *
 		floating_context->const_data.gauge_relative_fg_inner;
@@ -191,69 +154,119 @@ display_gauges (mod_gl_utils_context_t * utils_context,
 		size_factor *
 		floating_context->const_data.gauge_relative_fg_outer;
 
-	      if (gauge_meter->texture_alive)
+	      if (utils_context->textures_1x1.team_colors[team_color])
 		{
-		  glBindTexture (GL_TEXTURE_2D, gauge_meter->texture_alive);
-		  gluPartialDisk (floating_context->gauges.disk, inner,
-				  outer, slices, loops, start, sweep1);
+		  mod_gl_utils_bitmap_bind (utils_context,
+					    utils_context->
+					    textures_1x1.team_colors
+					    [team_color]);
+		  gluPartialDisk (floating_context->gauges.disk, inner, outer,
+				  slices, loops, start, sweep1);
 		}
 
-	      if (gauge_meter->texture_dead)
+	      if (utils_context->textures_1x1.team_color_dead)
 		{
-		  glBindTexture (GL_TEXTURE_2D, gauge_meter->texture_dead);
-		  gluPartialDisk (floating_context->gauges.disk, inner,
-				  outer, slices, loops, start + sweep1,
-				  sweep2);
+		  mod_gl_utils_bitmap_bind (utils_context,
+					    utils_context->
+					    textures_1x1.team_color_dead);
+		  gluPartialDisk (floating_context->gauges.disk, inner, outer,
+				  slices, loops, start + sweep1, sweep2);
 		}
+	      glMatrixMode (GL_MODELVIEW);
 	      glPopMatrix ();
+
 	      glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	      glEnable (GL_BLEND);
 
-	      if (gauge_text->texture_text_h > 0)
+	      text_h =
+		size_factor *
+		floating_context->const_data.gauge_relative_text_size;
+	      text_dw = size_factor *
+		floating_context->const_data.gauge_relative_text_dw;
+	      text_dh = size_factor *
+		floating_context->const_data.gauge_relative_text_dh;
+
+	      if (floating_context->game_state->game_struct->
+		  rules.respawn_team)
 		{
-		  text_h =
-		    size_factor *
-		    floating_context->const_data.gauge_relative_text_size;
-		  text_w =
-		    text_h * ((float) gauge_text->texture_text_w) /
-		    ((float) gauge_text->texture_text_h);
-		  if (gauge_text->texture_text_bg)
-		    {
-		      text_x1 =
-			(x1 + x2 - text_w) / 2.0f +
-			size_factor *
-			floating_context->const_data.gauge_relative_text_dw;
-		      text_y1 =
-			(y1 + y2 - text_h) / 2.0f +
-			size_factor *
-			floating_context->const_data.gauge_relative_text_dh;
-		      text_x2 = text_x1 + text_w;
-		      text_y2 = text_y1 + text_h;
-		      mod_gl_utils_display_texture_full (utils_context,
-							 gauge_text->
-							 texture_text_bg,
-							 text_x1, text_y1,
-							 text_x2, text_y2,
-							 gauge_text->
-							 texture_text_w,
-							 gauge_text->
-							 texture_text_h);
-		    }
-		  if (gauge_text->texture_text_fg)
+		  if (floating_context->gauges.percent_texts[i]
+		      && floating_context->gauges.
+		      percent_texts[i]->texture_h > 0)
 		    {
+		      text_w =
+			text_h *
+			((float) floating_context->gauges.percent_texts[i]->
+			 texture_w) /
+			((float) floating_context->gauges.
+			 percent_texts[i]->texture_h);
 		      text_x1 = (x1 + x2 - text_w) / 2.0f;
-		      text_y1 = (y1 + y2 - text_h) / 2.0f;
+		      text_y1 =
+			(y1 + y2) / 2.0f +
+			size_factor *
+			floating_context->
+			const_data.gauge_relative_percent_y1;
 		      text_x2 = text_x1 + text_w;
 		      text_y2 = text_y1 + text_h;
-		      mod_gl_utils_display_texture_full (utils_context,
-							 gauge_text->
-							 texture_text_fg,
-							 text_x1, text_y1,
-							 text_x2, text_y2,
-							 gauge_text->
-							 texture_text_w,
-							 gauge_text->
-							 texture_text_h);
+		      mod_gl_utils_shaded_text_display (utils_context,
+							floating_context->
+							gauges.
+							percent_texts[i],
+							text_x1, text_y1,
+							text_x2, text_y2,
+							text_dw, text_dh);
+		    }
+		  if (floating_context->gauges.frags_texts[i]
+		      && floating_context->gauges.frags_texts[i]->texture_h >
+		      0)
+		    {
+		      text_w =
+			text_h *
+			((float) floating_context->gauges.frags_texts[i]->
+			 texture_w) /
+			((float) floating_context->gauges.
+			 frags_texts[i]->texture_h);
+		      text_x1 = (x1 + x2 - text_w) / 2.0f;
+		      text_y1 =
+			(y1 + y2) / 2.0f +
+			size_factor *
+			floating_context->const_data.gauge_relative_frags_y1;
+		      text_x2 = text_x1 + text_w;
+		      text_y2 = text_y1 + text_h;
+		      mod_gl_utils_shaded_text_display (utils_context,
+							floating_context->
+							gauges.frags_texts[i],
+							text_x1, text_y1,
+							text_x2, text_y2,
+							text_dw, text_dh);
+		    }
+		}
+	      else
+		{
+		  if (floating_context->gauges.percent_texts[i]
+		      && floating_context->gauges.
+		      percent_texts[i]->texture_h > 0)
+		    {
+		      text_w =
+			text_h *
+			((float) floating_context->gauges.percent_texts[i]->
+			 texture_w) /
+			((float) floating_context->gauges.
+			 percent_texts[i]->texture_h);
+		      text_x1 = (x1 + x2 - text_w) / 2.0f;
+		      text_y1 =
+			(y1 + y2) / 2.0f +
+			size_factor *
+			floating_context->
+			const_data.gauge_relative_percent_only_y1;
+		      text_x2 = text_x1 + text_w;
+		      text_y2 = text_y1 + text_h;
+		      mod_gl_utils_shaded_text_display (utils_context,
+							floating_context->
+							gauges.
+							percent_texts[i],
+							text_x1, text_y1,
+							text_x2, text_y2,
+							text_dw, text_dh);
 		    }
 		}
 	      x2 = x1;
@@ -281,13 +294,12 @@ _mod_gl_hud_floating_display_hud (mod_gl_utils_context_t * utils_context,
 				  floating_context,
 				  lw6gui_look_t * look,
 				  lw6ker_game_state_t * game_state,
-				  lw6gui_main_cursor_t * main_cursor)
+				  lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_hud_floating_context_update_hud (utils_context, floating_context,
-					   look, game_state, main_cursor);
+					   look, game_state, local_cursors);
 
   mod_gl_utils_set_render_mode_2d_blend (utils_context);
-  set_hud_rules (utils_context);
   display_hud (utils_context, floating_context);
 }
 
@@ -296,12 +308,12 @@ mod_gl_hud_floating_display_hud (mod_gl_utils_context_t * utils_context,
 				 void *hud_context,
 				 lw6gui_look_t * look,
 				 lw6ker_game_state_t * game_state,
-				 lw6gui_main_cursor_t * main_cursor)
+				 lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_hud_floating_display_hud (utils_context,
 				    (_mod_gl_hud_floating_context_t *)
 				    hud_context, look, game_state,
-				    main_cursor);
+				    local_cursors);
 }
 
 static void
@@ -317,12 +329,11 @@ _mod_gl_hud_floating_display_score (mod_gl_utils_context_t * utils_context,
 				    floating_context,
 				    lw6gui_look_t * look,
 				    lw6ker_game_state_t * game_state,
-				    lw6gui_main_cursor_t * main_cursor)
+				    lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_hud_floating_context_update_score (utils_context, floating_context,
-					     look, game_state, main_cursor);
+					     look, game_state, local_cursors);
 
-  set_hud_rules (utils_context);
   display_score (utils_context, floating_context);
 }
 
@@ -331,10 +342,10 @@ mod_gl_hud_floating_display_score (mod_gl_utils_context_t * utils_context,
 				   void *hud_context,
 				   lw6gui_look_t * look,
 				   lw6ker_game_state_t * game_state,
-				   lw6gui_main_cursor_t * main_cursor)
+				   lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_hud_floating_display_score (utils_context,
 				      (_mod_gl_hud_floating_context_t *)
 				      hud_context, look, game_state,
-				      main_cursor);
+				      local_cursors);
 }
