@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,48 +27,18 @@
 #include "../../mod-gl.h"
 #include "gl-tactical-internal.h"
 
-static void
-set_texture_options (mod_gl_utils_context_t * utils_context,
-		     _mod_gl_hud_tactical_context_t * tactical_context)
-{
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
-}
-
 static void
 display_frame (mod_gl_utils_context_t * utils_context,
 	       _mod_gl_hud_tactical_context_t * tactical_context)
 {
-  float scale_w, scale_h;
-
-  scale_w =
-    mod_gl_utils_texture_scale (tactical_context->image_data.frame->w);
-  scale_h =
-    mod_gl_utils_texture_scale (tactical_context->image_data.frame->h);
-
   mod_gl_utils_set_render_mode_2d_blend (utils_context);
 
-  glBindTexture (GL_TEXTURE_2D, tactical_context->texture_data.frame);
-  set_texture_options (utils_context, tactical_context);
-
-  glMatrixMode (GL_TEXTURE);
-  glPushMatrix ();
-  glLoadIdentity ();
-  glBegin (GL_QUADS);
-  glTexCoord2d (0.0f, 0.0f);
-  glVertex3f (0.0f, 0.0f, 0.0f);	// top left
-  glTexCoord2d (scale_w, 0.0f);
-  glVertex3f (utils_context->video_mode.width, 0.0f, 0.0f);	// top right
-  glTexCoord2d (scale_w, scale_h);
-  glVertex3f (utils_context->video_mode.width, utils_context->video_mode.height, 0.0f);	// bottom right
-  glTexCoord2d (0.0f, scale_h);
-  glVertex3f (0.0f, utils_context->video_mode.height, 0.0f);	// bottom left
-  glEnd ();
-
-  glMatrixMode (GL_TEXTURE);
-  glPopMatrix ();
+  mod_gl_utils_bitmap_bind (utils_context,
+			    tactical_context->bitmap_data.frame);
+  mod_gl_utils_bitmap_display (utils_context,
+			       tactical_context->bitmap_data.frame, 0.0f,
+			       0.0f, utils_context->video_mode.width,
+			       utils_context->video_mode.height);
 }
 
 
@@ -78,7 +48,7 @@ _mod_gl_hud_tactical_display_hud (mod_gl_utils_context_t * utils_context,
 				  tactical_context,
 				  lw6gui_look_t * look,
 				  lw6ker_game_state_t * game_state,
-				  lw6gui_main_cursor_t * main_cursor)
+				  lw6pil_local_cursors_t * local_cursors)
 {
   display_frame (utils_context, tactical_context);
 }
@@ -88,12 +58,12 @@ mod_gl_hud_tactical_display_hud (mod_gl_utils_context_t * utils_context,
 				 void *hud_context,
 				 lw6gui_look_t * look,
 				 lw6ker_game_state_t * game_state,
-				 lw6gui_main_cursor_t * main_cursor)
+				 lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_hud_tactical_display_hud (utils_context,
 				    (_mod_gl_hud_tactical_context_t *)
 				    hud_context, look, game_state,
-				    main_cursor);
+				    local_cursors);
 }
 
 void
@@ -102,7 +72,7 @@ _mod_gl_hud_tactical_display_score (mod_gl_utils_context_t * utils_context,
 				    tactical_context,
 				    lw6gui_look_t * look,
 				    lw6ker_game_state_t * game_state,
-				    lw6gui_main_cursor_t * main_cursor)
+				    lw6pil_local_cursors_t * local_cursors)
 {
   //
 }
@@ -112,10 +82,10 @@ mod_gl_hud_tactical_display_score (mod_gl_utils_context_t * utils_context,
 				   void *hud_context,
 				   lw6gui_look_t * look,
 				   lw6ker_game_state_t * game_state,
-				   lw6gui_main_cursor_t * main_cursor)
+				   lw6pil_local_cursors_t * local_cursors)
 {
   _mod_gl_hud_tactical_display_score (utils_context,
 				      (_mod_gl_hud_tactical_context_t *)
 				      hud_context, look, game_state,
-				      main_cursor);
+				      local_cursors);
 }
