@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,16 +39,16 @@ extern void mod_gl_hud_tactical_display_hud (mod_gl_utils_context_t *
 					     lw6gui_look_t * look,
 					     lw6ker_game_state_t *
 					     game_state,
-					     lw6gui_main_cursor_t *
-					     main_cursor);
+					     lw6pil_local_cursors_t *
+					     local_cursors);
 extern void mod_gl_hud_tactical_display_score (mod_gl_utils_context_t *
 					       utils_context,
 					       void *hud_context,
 					       lw6gui_look_t * look,
 					       lw6ker_game_state_t *
 					       game_state,
-					       lw6gui_main_cursor_t *
-					       main_cursor);
+					       lw6pil_local_cursors_t *
+					       local_cursors);
 
 /*
  * In setup.c
