@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
 				     int n, float relative_text_width)
 {
   GLUquadricObj *cyl;
-  int64_t dt;
+  int32_t dt;
 
   cyl = gluNewQuadric ();
   if (cyl != NULL)
@@ -76,7 +76,7 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
 	_mod_gl_menu_cylinder_get_cylinder_y (utils_context, cylinder_context,
 					      i, n);
       dt =
-	mod_gl_utils_timer_uptime (utils_context) %
+	mod_gl_utils_timer_get_cycle (utils_context) %
 	cylinder_context->const_data.oscil_period;
       dy =
 	(cylinder_context->const_data.oscil_range1 / n) * sin (2.0f * M_PI *
