@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -512,7 +512,7 @@ mod_gl_utils_pump_events (mod_gl_utils_context_t * utils_context)
   mod_gl_utils_const_data_t *const_data = &(utils_context->const_data);
   int i, b;
 
-  timestamp = mod_gl_utils_timer_timestamp (utils_context);
+  timestamp = mod_gl_utils_timer_get_timestamp (utils_context);
   memset (&event, 0, sizeof (SDL_Event));
   while (SDL_PollEvent (&event))
     {
@@ -582,9 +582,11 @@ mod_gl_utils_pump_events (mod_gl_utils_context_t * utils_context)
 	  video_mode.width = event.resize.w;
 	  video_mode.height = event.resize.h;
 	  mod_gl_utils_resize_video_mode (utils_context, &video_mode);
+	  mod_gl_utils_timer_set_bitmap_refresh (utils_context);
 	  break;
 	case SDL_VIDEOEXPOSE:
 	  mod_gl_utils_sync_mode (utils_context, 0);
+	  mod_gl_utils_timer_set_bitmap_refresh (utils_context);
 	  break;
 	}
     }
