@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -443,37 +443,35 @@ mod_gl_utils_delete_scheduled_textures (mod_gl_utils_context_t * gfx_context)
 void
 mod_gl_utils_texture_update (mod_gl_utils_context_t *
 			     utils_context,
-			     GLuint texture, SDL_Surface * surface,
-			     int pixelize)
+			     GLuint texture, SDL_Surface * surface)
 {
-  /*
-   * Note that texture and surface need be the same size, else KABOUM!
-   * Usually, one should create the bitmap and the texture with
-   * _surface2texture then use this function afterwards on the same
-   * objects. Safer. Typical use is displaying armies/fighters.
-   */
-  glBindTexture (GL_TEXTURE_2D, texture);
-  if (pixelize)
+  if (texture && surface)
     {
-      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-    }
-  else
-    {
-      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-      glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-    }
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
-  glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
-  if (glIsTexture (texture))
-    {
-      glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, surface->w, surface->h,
-		       GL_RGBA, GL_UNSIGNED_BYTE, surface->pixels);
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("%d isn't a texture, can't call glTexSubImage2D"),
-		  texture);
+      /*
+       * Note that texture and surface need be the same size, else KABOUM!
+       * Usually, one should create the bitmap and the texture with
+       * _surface2texture then use this function afterwards on the same
+       * objects. Safer. Typical use is displaying armies/fighters.
+       */
+      glBindTexture (GL_TEXTURE_2D, texture);
+      /*
+         glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+         glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+         glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
+         glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
+       */
+      if (glIsTexture (texture))
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _("glTexSubImage2D on %d (%dx%d)"),
+		      texture, surface->w, surface->h);
+	  glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, surface->w, surface->h,
+			   GL_RGBA, GL_UNSIGNED_BYTE, surface->pixels);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("%d isn't a texture, can't call glTexSubImage2D"),
+		      texture);
+	}
     }
 }
