@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 #include "../gfx.h"
 #include "gl-utils/gl-utils.h"
+#include "gl-splash/gl-splash.h"
 #include "gl-background/gl-background.h"
 #include "gl-hud/gl-hud.h"
 #include "gl-menu/gl-menu.h"
@@ -33,6 +34,7 @@
 typedef struct _mod_gl_context_s
 {
   mod_gl_utils_context_t utils_context;
+  void *splash_context;
   mod_gl_background_backend_t *background_backend;
   mod_gl_hud_backend_t *hud_backend;
   mod_gl_menu_backend_t *menu_backend;
