@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -60,12 +60,17 @@
 #define LW6GUI_DISPLAY_PROGRESS   0x00000200
 #define LW6GUI_DISPLAY_LOG        0x00000400
 #define LW6GUI_DISPLAY_FPS        0x00000800
-#define LW6GUI_DISPLAY_RPS        0x00001000
-#define LW6GUI_DISPLAY_MOUSE      0x00002000
+#define LW6GUI_DISPLAY_MPS        0x00001000
+#define LW6GUI_DISPLAY_URL        0x00002000
+#define LW6GUI_DISPLAY_MOUSE      0x00004000
 
 #define LW6GUI_DISPLAY_DEBUG_ZONES    0x00010000
 #define LW6GUI_DISPLAY_DEBUG_GRADIENT 0x00020000
 
+#define LW6GUI_GFX_QUALITY_LOW      0
+#define LW6GUI_GFX_QUALITY_STANDARD 1
+#define LW6GUI_GFX_QUALITY_HIGH     2
+
 typedef struct lw6gui_video_mode_s
 {
   int width;
@@ -94,6 +99,7 @@ typedef struct lw6gui_look_s
 {
   u_int32_t id;
   float dynamic_zoom;
+  int gfx_quality;
   lw6map_style_t style;
 }
 lw6gui_look_t;
@@ -245,14 +251,6 @@ typedef struct lw6gui_viewport_s
 
 } lw6gui_viewport_t;
 
-typedef struct lw6gui_main_cursor_s
-{
-  u_int16_t cursor_id;
-  int x;
-  int y;
-  int mouse_controlled;
-} lw6gui_main_cursor_t;
-
 /* gui-button.c */
 extern void lw6gui_button_register_down (lw6gui_button_t * button,
 					 int64_t timestamp);
@@ -436,7 +434,7 @@ extern float lw6gui_smoother_get_value (lw6gui_smoother_t * smoother,
 					int64_t now);
 
 /* gui-test.c */
-extern int lw6gui_test ();
+extern int lw6gui_test (int mode);
 
 /* gui-videomode.c */
 extern int lw6gui_video_mode_find_closest (lw6gui_video_mode_t * closest,
