@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -110,6 +110,7 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MD5SUM);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_COPYRIGHT);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_LICENSE);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_URL);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_CONFIGURE_ARGS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_GCC_VERSION);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_CFLAGS);
@@ -117,13 +118,14 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_HOSTNAME);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_DATE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TIME);
-  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TARGET_CPU);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_HOST_CPU);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENDIANNESS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_POINTER_SIZE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_X86);
-  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TARGET_OS);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_HOST_OS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MS_WINDOWS);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_MAC_OS_X);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_GP2X);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_TOP_SRCDIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_PREFIX);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_DATADIR);
@@ -145,12 +147,15 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_PROFILER);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_GCOV);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_VALGRIND);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_BIN_ID);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_USER_DIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_CONFIG_FILE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_LOG_FILE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_PREFIX);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_MOD_DIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_DATA_DIR);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_MUSIC_DIR);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_MUSIC_PATH);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_MAP_DIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_MAP_PATH);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DEFAULT_SCRIPT_FILE);
@@ -162,6 +167,8 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_PREFIX);
   lw6sys_list_push_back (list, LW6DEF_SHOW_MOD_DIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_DATA_DIR);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_MUSIC_DIR);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_MUSIC_PATH);
   lw6sys_list_push_back (list, LW6DEF_SHOW_MAP_DIR);
   lw6sys_list_push_back (list, LW6DEF_SHOW_MAP_PATH);
   lw6sys_list_push_back (list, LW6DEF_SHOW_SCRIPT_FILE);
@@ -192,6 +199,8 @@ update_path (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_PREFIX);
   lw6sys_list_push_back (list, LW6DEF_MOD_DIR);
   lw6sys_list_push_back (list, LW6DEF_DATA_DIR);
+  lw6sys_list_push_back (list, LW6DEF_MUSIC_DIR);
+  lw6sys_list_push_back (list, LW6DEF_MUSIC_PATH);
   lw6sys_list_push_back (list, LW6DEF_MAP_DIR);
   lw6sys_list_push_back (list, LW6DEF_MAP_PATH);
   lw6sys_list_push_back (list, LW6DEF_SCRIPT_FILE);
@@ -299,7 +308,9 @@ update_graphics (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_HEIGHT);
   lw6sys_list_push_back (list, LW6DEF_FULLSCREEN);
   lw6sys_list_push_back (list, LW6DEF_GFX_BACKEND);
+  lw6sys_list_push_back (list, LW6DEF_GFX_QUALITY);
   lw6sys_list_push_back (list, LW6DEF_WINDOWED_MODE_LIMIT);
+  lw6sys_list_push_back (list, LW6DEF_CAPTURE);
 
   return ((*list) != NULL);
 }
@@ -324,6 +335,9 @@ update_sound (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SOUND_VOLUME);
   lw6sys_list_push_back (list, LW6DEF_MUSIC_VOLUME);
   lw6sys_list_push_back (list, LW6DEF_SND_BACKEND);
+  lw6sys_list_push_back (list, LW6DEF_AMBIANCE_FILE);
+  lw6sys_list_push_back (list, LW6DEF_AMBIANCE_FILTER);
+  lw6sys_list_push_back (list, LW6DEF_AMBIANCE_EXCLUDE);
 
   return ((*list) != NULL);
 }
@@ -345,6 +359,13 @@ lw6hlp_list_sound ()
 static int
 update_network (lw6sys_list_t ** list)
 {
+  lw6sys_list_push_back (list, LW6DEF_LOCAL);
+  lw6sys_list_push_back (list, LW6DEF_BIND_IP);
+  lw6sys_list_push_back (list, LW6DEF_BIND_PORT);
+  lw6sys_list_push_back (list, LW6DEF_CLI_BACKENDS);
+  lw6sys_list_push_back (list, LW6DEF_SRV_BACKENDS);
+  lw6sys_list_push_back (list, LW6DEF_PUBLIC_URL);
+
   return ((*list) != NULL);
 }
 
@@ -370,6 +391,7 @@ update_map (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_USE_RULES_XML);
   lw6sys_list_push_back (list, LW6DEF_USE_HINTS_XML);
   lw6sys_list_push_back (list, LW6DEF_USE_STYLE_XML);
+  lw6sys_list_push_back (list, LW6DEF_USE_MUSIC_FILE);
   lw6sys_list_push_back (list, LW6DEF_FORCE);
 
   return ((*list) != NULL);
@@ -394,6 +416,7 @@ update_map_rules (lw6sys_list_t ** list)
 {
   lw6sys_list_push_back (list, LW6DEF_TOTAL_TIME);
   lw6sys_list_push_back (list, LW6DEF_RESPAWN_TEAM);
+  lw6sys_list_push_back (list, LW6DEF_RESPAWN_RANDOM_PLACE);
   lw6sys_list_push_back (list, LW6DEF_MOVES_PER_ROUND);
   lw6sys_list_push_back (list, LW6DEF_SPREADS_PER_ROUND);
   lw6sys_list_push_back (list, LW6DEF_ROUNDS_PER_SEC);
@@ -444,6 +467,10 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_START_POSITION_MODE);
   lw6sys_list_push_back (list, LW6DEF_COLOR_CONFLICT_MODE);
   lw6sys_list_push_back (list, LW6DEF_SPREAD_THREAD);
+  lw6sys_list_push_back (list, LW6DEF_GLUE_POWER);
+  lw6sys_list_push_back (list, LW6DEF_BOOST_POWER);
+  lw6sys_list_push_back (list, LW6DEF_DANGER_POWER);
+  lw6sys_list_push_back (list, LW6DEF_MEDICINE_POWER);
 
   return ((*list) != NULL);
 }
@@ -473,12 +500,19 @@ update_map_hints (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_MIN_MAP_SURFACE);
   lw6sys_list_push_back (list, LW6DEF_MAX_MAP_SURFACE);
   lw6sys_list_push_back (list, LW6DEF_FIGHTER_SCALE);
+  lw6sys_list_push_back (list, LW6DEF_DOWNSIZE_USING_FIGHTER_SCALE);
+  lw6sys_list_push_back (list, LW6DEF_UPSIZE_USING_FIGHTER_SCALE);
+  lw6sys_list_push_back (list, LW6DEF_DOWNSIZE_USING_BENCH_VALUE);
+  lw6sys_list_push_back (list, LW6DEF_UPSIZE_USING_BENCH_VALUE);
   lw6sys_list_push_back (list, LW6DEF_GUESS_COLORS);
   lw6sys_list_push_back (list, LW6DEF_BACKGROUND_COLOR_AUTO);
   lw6sys_list_push_back (list, LW6DEF_HUD_COLOR_AUTO);
   lw6sys_list_push_back (list, LW6DEF_MENU_COLOR_AUTO);
   lw6sys_list_push_back (list, LW6DEF_VIEW_COLOR_AUTO);
   lw6sys_list_push_back (list, LW6DEF_SYSTEM_COLOR_AUTO);
+  lw6sys_list_push_back (list, LW6DEF_WALL_GREASE);
+  lw6sys_list_push_back (list, LW6DEF_GUESS_MOVES_PER_SEC);
+  lw6sys_list_push_back (list, LW6DEF_SPEED);
 
   return ((*list) != NULL);
 }
@@ -540,6 +574,7 @@ update_map_style (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_VIEW_COLOR_MAP_FG);
   lw6sys_list_push_back (list, LW6DEF_SYSTEM_COLOR_BG);
   lw6sys_list_push_back (list, LW6DEF_SYSTEM_COLOR_FG);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_DEAD);
   lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_RED);
   lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_GREEN);
   lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_BLUE);
@@ -550,6 +585,9 @@ update_map_style (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_LIGHTBLUE);
   lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_PURPLE);
   lw6sys_list_push_back (list, LW6DEF_TEAM_COLOR_PINK);
+  lw6sys_list_push_back (list, LW6DEF_MUSIC_FILE);
+  lw6sys_list_push_back (list, LW6DEF_MUSIC_FILTER);
+  lw6sys_list_push_back (list, LW6DEF_MUSIC_EXCLUDE);
 
   return ((*list) != NULL);
 }
@@ -612,10 +650,11 @@ static int
 update_tuning (lw6sys_list_t ** list)
 {
   lw6sys_list_push_back (list, LW6DEF_PEDIGREE);
-  lw6sys_list_push_back (list, LW6DEF_TARGET);
+  lw6sys_list_push_back (list, LW6DEF_HOST);
   lw6sys_list_push_back (list, LW6DEF_AUDIT);
   lw6sys_list_push_back (list, LW6DEF_MODULES);
   lw6sys_list_push_back (list, LW6DEF_RESET);
+  lw6sys_list_push_back (list, LW6DEF_RESET_CONFIG_ON_UPGRADE);
   lw6sys_list_push_back (list, LW6DEF_LOG_LEVEL);
   lw6sys_list_push_back (list, LW6DEF_TARGET_FPS);
   lw6sys_list_push_back (list, LW6DEF_IO_PER_SEC);
@@ -636,7 +675,8 @@ update_tuning (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_PROGRESS);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_LOG);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_FPS);
-  lw6sys_list_push_back (list, LW6DEF_DISPLAY_RPS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_MPS);
+  lw6sys_list_push_back (list, LW6DEF_DISPLAY_URL);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_MOUSE);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_DEBUG_ZONES);
   lw6sys_list_push_back (list, LW6DEF_DISPLAY_DEBUG_GRADIENT);
@@ -645,6 +685,10 @@ update_tuning (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_QUICK_START);
   lw6sys_list_push_back (list, LW6DEF_DEMO);
   lw6sys_list_push_back (list, LW6DEF_BENCH);
+  lw6sys_list_push_back (list, LW6DEF_BENCH_VALUE);
+  lw6sys_list_push_back (list, LW6DEF_MAGIC_NUMBER);
+  lw6sys_list_push_back (list, LW6DEF_BIN_ID);
+  lw6sys_list_push_back (list, LW6DEF_CHECK);
   lw6sys_list_push_back (list, LW6DEF_BOT_SPEED);
   lw6sys_list_push_back (list, LW6DEF_BOT_IQ);
   lw6sys_list_push_back (list, LW6DEF_DEBUG_TEAM_ID);
@@ -652,6 +696,7 @@ update_tuning (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_LOG_TIMEOUT);
   lw6sys_list_push_back (list, LW6DEF_GFX_CPU_USAGE);
   lw6sys_list_push_back (list, LW6DEF_DIRTY_READ);
+  lw6sys_list_push_back (list, LW6DEF_GFX_DEBUG);
 
   return ((*list) != NULL);
 }
