@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,8 +26,17 @@
 
 #include "img.h"
 
+/**
+ * lw6img_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @img module test suite.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6img_test ()
+lw6img_test (int mode)
 {
   int ret = 0;
 
@@ -36,10 +45,10 @@ lw6img_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6cfg_test ();
-      lw6map_test ();
-      lw6ker_test ();
+      lw6sys_test (mode);
+      lw6cfg_test (mode);
+      lw6map_test (mode);
+      lw6ker_test (mode);
     }
 
   ret = 1;
