@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,9 +28,7 @@
 #include "../map/map.h"
 #include "../ker/ker.h"
 
-/*
- * In test.c
- */
-extern int lw6img_test ();
+/* img-test.c */
+extern int lw6img_test (int mode);
 
 #endif
