@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -69,12 +69,19 @@ _lw6ker_cursor_check_server_id (lw6ker_cursor_t * cursor, u_int64_t server_id)
 
 int
 _lw6ker_cursor_get_start_xy (int32_t * x, int32_t * y, int team_color,
+			     int random_place, int random_seed,
 			     lw6sys_whd_t * shape, lw6map_rules_t * rules)
 {
   int ret = 1;
   int32_t px = 50;
   int32_t py = 50;
 
+  if (random_place)
+    {
+      team_color =
+	((team_color + random_seed) & 0xFFFF) % LW6MAP_NB_TEAM_COLORS;
+    }
+
   switch (team_color)
     {
     case LW6MAP_TEAM_COLOR_RED:
