@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -447,7 +447,7 @@ lw6ker_game_state_add_cursor (lw6ker_game_state_t * game_state,
 	      if (lw6ker_game_state_team_exists (game_state, real_team_color))
 		{
 		  if (_lw6ker_cursor_get_start_xy
-		      (&x, &y, real_team_color,
+		      (&x, &y, real_team_color, 0, 0,
 		       &(game_state->map_state.shape), rules))
 		    {
 		      ret =
@@ -590,7 +590,8 @@ lw6ker_game_state_set_cursor (lw6ker_game_state_t * game_state,
 }
 
 int
-_lw6ker_game_state_add_team (lw6ker_game_state_t * game_state, int team_color)
+_lw6ker_game_state_add_team (lw6ker_game_state_t * game_state, int team_color,
+			     int random_place)
 {
   int ret = 0;
   int32_t i;
@@ -610,7 +611,8 @@ _lw6ker_game_state_add_team (lw6ker_game_state_t * game_state, int team_color)
       int32_t x;
       int32_t y;
 
-      _lw6ker_cursor_get_start_xy (&x, &y, team_color,
+      _lw6ker_cursor_get_start_xy (&x, &y, team_color, random_place,
+				   lw6ker_game_state_get_rounds (game_state),
 				   &(game_state->map_state.shape), rules);
       desired_center.x = x;
       desired_center.y = y;
@@ -686,7 +688,7 @@ lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
 
   if (check_server_id (game_state, server_id))
     {
-      ret = _lw6ker_game_state_add_team (game_state, team_color);
+      ret = _lw6ker_game_state_add_team (game_state, team_color, 0);
       if (ret)
 	{
 	  /*
@@ -924,8 +926,8 @@ lw6ker_game_state_do_move (lw6ker_game_state_t *
   if (!game_state->over)
     {
       lw6ker_map_state_move_fighters (&(game_state->map_state),
-				      lw6sys_checksum_int32 (game_state->
-							     rounds) %
+				      lw6sys_checksum_int32
+				      (game_state->rounds) %
 				      LW6KER_NB_PARITIES,
 				      &(game_state->game_struct->rules),
 				      game_state->game_struct->rules.
@@ -988,7 +990,9 @@ lw6ker_game_state_finish_round (lw6ker_game_state_t * game_state)
 		  /*
 		   * Cancelling then adding will have the effect to repopulate the team
 		   */
-		  _lw6ker_game_state_add_team (game_state, team_color);
+		  _lw6ker_game_state_add_team (game_state, team_color,
+					       game_state->game_struct->
+					       rules.respawn_random_place);
 		  game_state->map_state.armies.frags[team_color]--;
 		}
 	      else
