@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ _lw6ker_map_state_init (lw6ker_map_state_t * map_state,
 
   map_state->map_struct = map_struct;
   map_state->shape = map_struct->shape;
-  map_state->shape_surface = map_struct->shape_surface;
+  map_state->shape_surface = map_struct->nb_places;
 
   ret = 1;
 
@@ -473,7 +473,7 @@ lw6ker_map_state_get_fighter_safe (lw6ker_map_state_t * map_state,
   int fighter_id;
 
   if (x >= 0
-      && x <= map_state->shape.w && y >= 0 && y < map_state->shape.h && z >= 0
+      && x < map_state->shape.w && y >= 0 && y < map_state->shape.h && z >= 0
       && z < map_state->shape.d)
     {
       fighter_id =
@@ -639,6 +639,7 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
   context.parity = parity;
   context.team_mask = team_mask;
   context.map_state = map_state;
+  context.map_struct = map_state->map_struct;
   context.rules = *rules;
   context.armies = &(map_state->armies);
   context.active_fighters = context.armies->active_fighters;
