@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -67,12 +67,17 @@ _lw6ker_map_struct_update_checksum (lw6ker_map_struct_t *
   int i;
 
   lw6sys_checksum_update_whd (checksum, &(map_struct->shape));
-  lw6sys_checksum_update_int32 (checksum, map_struct->shape_surface);
+  lw6sys_checksum_update_int32 (checksum, map_struct->nb_places);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_zones);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_slots);
   lw6sys_checksum_update_int32 (checksum, map_struct->nb_usable_slots);
   lw6sys_checksum_update_int32 (checksum, map_struct->room_for_armies);
   lw6sys_checksum_update_int32 (checksum, map_struct->max_zone_size);
+  for (i = 0; i < map_struct->nb_places; ++i)
+    {
+      _lw6ker_place_struct_update_checksum (&(map_struct->places[i]),
+					    checksum);
+    }
   for (i = 0; i < map_struct->nb_zones; ++i)
     {
       _lw6ker_zone_struct_update_checksum (&(map_struct->zones[i]), checksum);
@@ -101,7 +106,7 @@ _lw6ker_map_struct_lazy_compare (lw6ker_map_struct_t *
 	  ret = (map_struct_a->shape.w == map_struct_b->shape.w) &&
 	    (map_struct_a->shape.h == map_struct_b->shape.h) &&
 	    (map_struct_a->shape.d == map_struct_b->shape.d) &&
-	    (map_struct_a->shape_surface == map_struct_b->shape_surface) &&
+	    (map_struct_a->nb_places == map_struct_b->nb_places) &&
 	    (map_struct_a->nb_zones == map_struct_b->nb_zones) &&
 	    (map_struct_a->nb_slots == map_struct_b->nb_slots) &&
 	    (map_struct_a->nb_usable_slots == map_struct_b->nb_usable_slots)
@@ -212,8 +217,8 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 			      j = relative_index (level, x, y - 1, z);
 			      if (ret->zones[j].used && i != j)
 				{
-				  ret->zones[i].link[LW6KER_DIR_NNW] =
-				    ret->zones[i].link[LW6KER_DIR_NNE] = j;
+				  ret->zones[i].link[LW6KER_DIR_NNW] = j;
+				  ret->zones[i].link[LW6KER_DIR_NNE] = j;
 				}
 			      j = relative_index (level, x + 1, y - 1, z);
 			      if (ret->zones[j].used && i != j)
@@ -223,8 +228,8 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 			      j = relative_index (level, x + 1, y, z);
 			      if (ret->zones[j].used && i != j)
 				{
-				  ret->zones[i].link[LW6KER_DIR_ENE] =
-				    ret->zones[i].link[LW6KER_DIR_ESE] = j;
+				  ret->zones[i].link[LW6KER_DIR_ENE] = j;
+				  ret->zones[i].link[LW6KER_DIR_ESE] = j;
 				}
 			      j = relative_index (level, x + 1, y + 1, z);
 			      if (ret->zones[j].used && i != j)
@@ -234,8 +239,8 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 			      j = relative_index (level, x, y + 1, z);
 			      if (ret->zones[j].used && i != j)
 				{
-				  ret->zones[i].link[LW6KER_DIR_SSE] =
-				    ret->zones[i].link[LW6KER_DIR_SSW] = j;
+				  ret->zones[i].link[LW6KER_DIR_SSE] = j;
+				  ret->zones[i].link[LW6KER_DIR_SSW] = j;
 				}
 			      j = relative_index (level, x - 1, y + 1, z);
 			      if (ret->zones[j].used && i != j)
@@ -245,8 +250,8 @@ draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 			      j = relative_index (level, x - 1, y, z);
 			      if (ret->zones[j].used && i != j)
 				{
-				  ret->zones[i].link[LW6KER_DIR_WSW] =
-				    ret->zones[i].link[LW6KER_DIR_WNW] = j;
+				  ret->zones[i].link[LW6KER_DIR_WSW] = j;
+				  ret->zones[i].link[LW6KER_DIR_WNW] = j;
 				}
 			      j = relative_index (level, x - 1, y - 1, z);
 			      if (ret->zones[j].used && i != j)
@@ -541,6 +546,185 @@ draft_zones_group (lw6map_level_t * level, draft_zones_t * draft_zones,
   return found;
 }
 
+static int
+_fix_one_way (lw6ker_map_struct_t * map_struct, lw6map_level_t * level)
+{
+  int ret = 0;
+  int x, y;
+  int i;
+  int one_way_north = 0;
+  int one_way_east = 0;
+  int one_way_south = 0;
+  int one_way_west = 0;
+  int allow_north = 0;
+  int allow_east = 0;
+  int allow_south = 0;
+  int allow_west = 0;
+  lw6ker_zone_struct_t *zone_struct;
+
+  for (i = 0; i < map_struct->nb_zones; ++i)
+    {
+      zone_struct = &(map_struct->zones[i]);
+      for (y = 0; y < zone_struct->size; y++)
+	{
+	  for (x = 0; x < zone_struct->size; x++)
+	    {
+	      one_way_north = 0;
+	      one_way_east = 0;
+	      one_way_south = 0;
+	      one_way_west = 0;
+	      one_way_north +=
+		lw6map_meta_layer_get (&level->body.one_way_north,
+				       zone_struct->pos.x + x,
+				       zone_struct->pos.y + y);
+	      one_way_east +=
+		lw6map_meta_layer_get (&level->body.one_way_east,
+				       zone_struct->pos.x + x,
+				       zone_struct->pos.y + y);
+	      one_way_south +=
+		lw6map_meta_layer_get (&level->body.one_way_south,
+				       zone_struct->pos.x + x,
+				       zone_struct->pos.y + y);
+	      one_way_west +=
+		lw6map_meta_layer_get (&level->body.one_way_west,
+				       zone_struct->pos.x + x,
+				       zone_struct->pos.y + y);
+	    }
+	}
+      if (one_way_north == one_way_south)
+	{
+	  /*
+	   * This traps the case where both are equal to zero and
+	   * also the case where there's a conflict between two
+	   * directions. In such a case we just leave the way open
+	   * rather than risk isolated zones.
+	   */
+	  allow_north = 1;
+	  allow_south = 1;
+	}
+      else
+	{
+	  if (one_way_north > one_way_south)
+	    {
+	      allow_north = 1;
+	      allow_south = 0;
+	    }
+	  else
+	    {
+	      allow_north = 0;
+	      allow_south = 1;
+	    }
+	}
+      if (one_way_east == one_way_west)
+	{
+	  /*
+	   * This traps the case where both are equal to zero and
+	   * also the case where there's a conflict between two
+	   * directions. In such a case we just leave the way open
+	   * rather than risk isolated zones.
+	   */
+	  allow_east = 1;
+	  allow_west = 1;
+	}
+      else
+	{
+	  if (one_way_east > one_way_west)
+	    {
+	      allow_east = 1;
+	      allow_west = 0;
+	    }
+	  else
+	    {
+	      allow_east = 0;
+	      allow_west = 1;
+	    }
+	}
+
+      zone_struct->one_way_dir_even = -1;
+      zone_struct->one_way_dir_odd = -1;
+      if ((!allow_north) && allow_east && allow_west)
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_SSE;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_SSW;
+	}
+      if ((!allow_east) && allow_north && allow_south)
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_WSW;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_WNW;
+	}
+      if ((!allow_south) && allow_east && allow_west)
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_NNW;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_NNE;
+	}
+      if ((!allow_west) && allow_north && allow_south)
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_ENE;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_ESE;
+	}
+      if ((!allow_north) && (!allow_east))
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_SW;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_SW;
+	}
+      if ((!allow_east) && (!allow_south))
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_NW;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_NW;
+	}
+      if ((!allow_south) && (!allow_west))
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_NE;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_NE;
+	}
+      if ((!allow_west) && (!allow_north))
+	{
+	  zone_struct->one_way_dir_even = LW6KER_DIR_SE;
+	  zone_struct->one_way_dir_odd = LW6KER_DIR_SE;
+	}
+      if (!allow_north)
+	{
+	  zone_struct->link[LW6KER_DIR_ESE] = -1;
+	  zone_struct->link[LW6KER_DIR_SE] = -1;
+	  zone_struct->link[LW6KER_DIR_SSE] = -1;
+	  zone_struct->link[LW6KER_DIR_SSW] = -1;
+	  zone_struct->link[LW6KER_DIR_SW] = -1;
+	  zone_struct->link[LW6KER_DIR_WSW] = -1;
+	}
+      if (!allow_east)
+	{
+	  zone_struct->link[LW6KER_DIR_SSW] = -1;
+	  zone_struct->link[LW6KER_DIR_SW] = -1;
+	  zone_struct->link[LW6KER_DIR_WSW] = -1;
+	  zone_struct->link[LW6KER_DIR_WNW] = -1;
+	  zone_struct->link[LW6KER_DIR_NW] = -1;
+	  zone_struct->link[LW6KER_DIR_NNW] = -1;
+	}
+      if (!allow_south)
+	{
+	  zone_struct->link[LW6KER_DIR_WNW] = -1;
+	  zone_struct->link[LW6KER_DIR_NW] = -1;
+	  zone_struct->link[LW6KER_DIR_NNW] = -1;
+	  zone_struct->link[LW6KER_DIR_NNE] = -1;
+	  zone_struct->link[LW6KER_DIR_NE] = -1;
+	  zone_struct->link[LW6KER_DIR_ENE] = -1;
+	}
+      if (!allow_west)
+	{
+	  zone_struct->link[LW6KER_DIR_NNE] = -1;
+	  zone_struct->link[LW6KER_DIR_NE] = -1;
+	  zone_struct->link[LW6KER_DIR_ENE] = -1;
+	  zone_struct->link[LW6KER_DIR_ESE] = -1;
+	  zone_struct->link[LW6KER_DIR_SE] = -1;
+	  zone_struct->link[LW6KER_DIR_SSE] = -1;
+	}
+    }
+
+  ret = 1;
+
+  return ret;
+}
+
 /*
  * Transform the temporary draft_zones_t into the proper
  * final MAP_STRUCT. The major change is to actually
@@ -578,7 +762,7 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
     }
 
   map_struct->shape = draft_zones->shape;
-  map_struct->shape_surface = w * h;
+  map_struct->nb_places = w * h;
   map_struct->nb_slots = w * h * d;
   map_struct->nb_zones = nb_zones;
   map_struct->max_zone_size = draft_zones->max_zone_size;
@@ -639,6 +823,170 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
   return ret;
 }
 
+/*
+ * Init places, that is, mostly read and aggregate meta-layer info
+ */
+static int
+init_places (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
+	     lw6sys_progress_t * progress)
+{
+  int ret = 0;
+  int x, y;
+  int i;
+  lw6sys_whd_t shape;
+  int32_t act_incr = 0;
+  int glue_power;
+  int boost_power;
+  int danger_power;
+  int medicine_power;
+  u_int32_t meta_layer_value;
+  int act_incr_min = 0;
+  int act_incr_max = 0;
+  int danger_correction = 0;
+  int medicine_correction = 0;
+
+  lw6sys_progress_begin (progress);
+
+  shape = map_struct->shape;
+  map_struct->places =
+    (lw6ker_place_struct_t *) LW6SYS_CALLOC (map_struct->shape.w *
+					     map_struct->shape.h *
+					     sizeof (lw6ker_place_struct_t));
+
+  if (map_struct->places)
+    {
+      for (y = 0; y < shape.h; ++y)
+	{
+	  for (x = 0; x < shape.w; ++x)
+	    {
+	      map_struct->places[lw6ker_map_struct_place_index
+				 (map_struct, x, y)].act_incr =
+		LW6KER_ACT_LIMIT;
+	      /*
+	       * no need to set health_correction to 0, was done 
+	       * by the CALLOC
+	       */
+	    }
+	}
+
+      glue_power = level->param.rules.glue_power;
+      if (level->body.glue.data && glue_power > 0)
+	{
+	  if (lw6sys_shape_is_same_xy (&level->body.glue.shape, &shape))
+	    {
+	      act_incr_min = LW6KER_ACT_LIMIT / glue_power;
+	      for (y = 0; y < shape.h; ++y)
+		{
+		  for (x = 0; x < shape.w; ++x)
+		    {
+		      meta_layer_value =
+			lw6map_meta_layer_get (&level->body.glue, x, y);
+		      act_incr =
+			((0xFF - meta_layer_value) * LW6KER_ACT_LIMIT +
+			 meta_layer_value * act_incr_min) / 0xFF -
+			LW6KER_ACT_LIMIT;
+		      map_struct->places[lw6ker_map_struct_place_index
+					 (map_struct, x, y)].act_incr +=
+			act_incr;
+		    }
+		}
+	    }
+	}
+
+      boost_power = level->param.rules.boost_power;
+      if (level->body.boost.data && boost_power > 0)
+	{
+	  if (lw6sys_shape_is_same_xy (&level->body.boost.shape, &shape))
+	    {
+	      act_incr_max = LW6KER_ACT_LIMIT * boost_power;
+	      for (y = 0; y < shape.h; ++y)
+		{
+		  for (x = 0; x < shape.w; ++x)
+		    {
+		      meta_layer_value =
+			lw6map_meta_layer_get (&level->body.boost, x, y);
+		      act_incr =
+			((0xFF - meta_layer_value) * LW6KER_ACT_LIMIT +
+			 meta_layer_value * act_incr_max) / 0xFF -
+			LW6KER_ACT_LIMIT;
+		      map_struct->places[lw6ker_map_struct_place_index
+					 (map_struct, x, y)].act_incr +=
+			act_incr;
+		    }
+		}
+	    }
+	}
+
+      danger_power = level->param.rules.danger_power;
+      if (level->body.danger.data && danger_power > 0)
+	{
+	  if (lw6sys_shape_is_same_xy (&level->body.danger.shape, &shape))
+	    {
+	      for (y = 0; y < shape.h; ++y)
+		{
+		  for (x = 0; x < shape.w; ++x)
+		    {
+		      meta_layer_value =
+			lw6map_meta_layer_get (&level->body.danger, x, y);
+		      danger_correction =
+			(meta_layer_value * danger_power) / 0xFF;
+		      map_struct->places[lw6ker_map_struct_place_index
+					 (map_struct, x,
+					  y)].health_correction -=
+			danger_correction;
+		    }
+		}
+	    }
+	}
+
+      medicine_power = level->param.rules.medicine_power;
+      if (level->body.medicine.data && medicine_power > 0)
+	{
+	  if (lw6sys_shape_is_same_xy (&level->body.medicine.shape, &shape))
+	    {
+	      for (y = 0; y < shape.h; ++y)
+		{
+		  for (x = 0; x < shape.w; ++x)
+		    {
+		      meta_layer_value =
+			lw6map_meta_layer_get (&level->body.medicine, x, y);
+		      medicine_correction =
+			(meta_layer_value * medicine_power) / 0xFF;
+		      map_struct->places[lw6ker_map_struct_place_index
+					 (map_struct, x,
+					  y)].health_correction +=
+			medicine_correction;
+		    }
+		}
+	    }
+	}
+
+      for (y = 0; y < shape.h; ++y)
+	{
+	  for (x = 0; x < shape.w; ++x)
+	    {
+	      i = lw6ker_map_struct_place_index (map_struct, x, y);
+	      map_struct->places[i].act_incr =
+		lw6sys_max (1, map_struct->places[i].act_incr);
+	      /*
+	       * health_correction need not be fixed
+	       */
+	    }
+	}
+
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to create places for map struct"));
+    }
+
+  lw6sys_progress_end (progress);
+
+  return ret;
+}
+
 /*
  * Create the slots, the main interest in doing this is to
  * have a quick way to get the right zone for a given (x,y).
@@ -648,6 +996,10 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
 	    lw6sys_progress_t * progress)
 {
   int ret = 0;
+  lw6sys_progress_t progress1;
+  lw6sys_progress_t progress2;
+
+  lw6sys_progress_split (&progress1, &progress2, progress);
 
   lw6sys_progress_begin (progress);
 
@@ -657,7 +1009,7 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
 					    map_struct->shape.d *
 					    sizeof (lw6ker_slot_struct_t));
 
-  if (map_struct)
+  if (map_struct->slots)
     {
       int32_t i, x, y, z;
 
@@ -666,9 +1018,11 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
       /*
        * Set up the id lookup table
        */
-      for (z = 0; z < map_struct->shape.d; ++z)
+      for (y = 0; y < map_struct->shape.h; ++y)
 	{
-	  for (y = 0; y < map_struct->shape.h; ++y)
+	  lw6sys_progress_update (&progress1, 0, map_struct->shape.h, y);
+	  // z after y so that progress is more fluid
+	  for (z = 0; z < map_struct->shape.d; ++z)
 	    {
 	      for (x = 0; x < map_struct->shape.w; ++x)
 		{
@@ -679,6 +1033,7 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
 
       for (i = 0; i < map_struct->nb_zones; ++i)
 	{
+	  lw6sys_progress_update (&progress2, 0, map_struct->nb_zones, i);
 	  zone = &map_struct->zones[i];
 	  for (y = 0; y < map_struct->zones[i].size; ++y)
 	    {
@@ -741,10 +1096,11 @@ _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
   lw6sys_progress_t progress2;
   lw6sys_progress_t progress3;
   lw6sys_progress_t progress4;
+  lw6sys_progress_t progress5;
 
   lw6sys_progress_begin (progress);
-  lw6sys_progress_split4 (&progress1, &progress2, &progress3, &progress4,
-			  progress);
+  lw6sys_progress_split5 (&progress1, &progress2, &progress3, &progress4,
+			  &progress5, progress);
 
   memset (map_struct, 0, sizeof (lw6ker_map_struct_t));
 
@@ -753,7 +1109,8 @@ _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
     {
       int32_t i;
 
-      lw6sys_progress_begin (&progress2);
+      lw6sys_progress_begin (&progress3);
+
       ret = 1;
 
       i = 1;
@@ -769,17 +1126,19 @@ _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
       while (i <= level->param.rules.max_zone_size / 2
 	     && draft_zones_group (level, draft_zones, i))
 	{
-	  lw6sys_progress_update (&progress2, 0, progress_n, progress_i++);
+	  lw6sys_progress_update (&progress3, 0, progress_n, progress_i++);
 	  i *= 2;
 	}
-      lw6sys_progress_end (&progress2);
+      lw6sys_progress_end (&progress3);
 
       ret = ret
-	&& draft_zones_to_map_struct (map_struct, draft_zones, &progress3);
+	&& draft_zones_to_map_struct (map_struct, draft_zones, &progress4);
 
       draft_zones_free (draft_zones);
 
-      ret = ret && init_slots (map_struct, level, &progress4);
+      ret = ret && _fix_one_way (map_struct, level);
+      ret = ret && init_slots (map_struct, level, &progress5);
+      ret = ret && init_places (map_struct, level, &progress1);
 
       lw6ker_map_struct_sanity_check (map_struct);
 
@@ -805,6 +1164,10 @@ _lw6ker_map_struct_clear (lw6ker_map_struct_t * map_struct)
 {
   if (map_struct)
     {
+      if (map_struct->places)
+	{
+	  LW6SYS_FREE (map_struct->places);
+	}
       if (map_struct->zones)
 	{
 	  LW6SYS_FREE (map_struct->zones);
@@ -885,7 +1248,7 @@ lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct)
 {
   int ret = 1;
   int x, y, z, w, h, d;
-  int shape_surface, nb_zones, nb_slots;
+  int nb_places, nb_zones, nb_slots;
   int zone_id;
   int i, j;
   int z1, z2;
@@ -893,15 +1256,15 @@ lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct)
   w = map_struct->shape.w;
   h = map_struct->shape.h;
   d = map_struct->shape.d;
-  shape_surface = map_struct->shape_surface;
+  nb_places = map_struct->nb_places;
   nb_zones = map_struct->nb_zones;
   nb_slots = map_struct->nb_slots;
 
-  if (shape_surface != w * h)
+  if (nb_places != w * h)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("inconsistent shape_surface=%d shape=%dx%d"),
-		  shape_surface, w, h);
+		  _("inconsistent nb_places=%d shape=%dx%d"),
+		  nb_places, w, h);
       ret = 0;
     }
 
