@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,11 +29,12 @@
 #define TEST_MAP_WIDTH 72
 #define TEST_MAP_HEIGHT 24
 #define TEST_MAP_NB_LAYERS 5
+#define TEST_MAP_NOISE_PERCENT 20
 #define TEST_NB_ROUNDS 100
-#define TEST_GAME_STRUCT_CHECKSUM 0xf65ea4db
-#define TEST_GAME_STATE_CHECKSUM 0xe077bc23
-#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x98aca3a9
-#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0xab604ac9
+#define TEST_GAME_STRUCT_CHECKSUM 0xd4603ab9
+#define TEST_GAME_STATE_CHECKSUM 0xbe2b9495
+#define TEST_GAME_STATE_POPULATE_CHECKSUM 0xeaf7fea4
+#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x51a30354
 #define TEST_SERVER_ID 0x1234123412341234LL
 #define TEST_CURSOR1_ID 0x1234
 #define TEST_CURSOR2_ID 0x2345
@@ -95,8 +96,8 @@ test_struct ()
 
     ret = 0;
     level =
-      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
-			  TEST_MAP_NB_LAYERS);
+      lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			     TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -133,8 +134,8 @@ test_state ()
 
     ret = 0;
     level =
-      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
-			  TEST_MAP_NB_LAYERS);
+      lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			     TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -181,8 +182,8 @@ test_population ()
     ret = 0;
 
     level =
-      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
-			  TEST_MAP_NB_LAYERS);
+      lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			     TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -246,8 +247,8 @@ test_algorithm ()
 
     ret = 0;
     level =
-      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
-			  TEST_MAP_NB_LAYERS);
+      lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			     TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -362,8 +363,8 @@ test_dup ()
 
     ret = 0;
     level =
-      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
-			  TEST_MAP_NB_LAYERS);
+      lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			     TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
     if (level)
       {
 	game_struct = lw6ker_game_struct_new (level, NULL);
@@ -435,8 +436,20 @@ test_team_mask ()
   return ret;
 }
 
+/**
+ * lw6ker_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @ker module test suite. Will perform deep checksums
+ * and *really* check many things. If this passes, the algorithm
+ * is fine. What could make it fail is a serious bug and/or some
+ * weird combination of endianess, byte alignment...
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6ker_test ()
+lw6ker_test (int mode)
 {
   int ret = 0;
 
@@ -445,8 +458,8 @@ lw6ker_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6map_test ();
+      lw6sys_test (mode);
+      lw6map_test (mode);
     }
 
   ret = test_team_mask () && test_struct () && test_state ()
