@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,4 +39,6 @@ _lw6ker_zone_struct_update_checksum (lw6ker_zone_struct_t * zone_struct,
     {
       lw6sys_checksum_update_int32 (checksum, zone_struct->link[i]);
     }
+  lw6sys_checksum_update_int32 (checksum, zone_struct->one_way_dir_even);
+  lw6sys_checksum_update_int32 (checksum, zone_struct->one_way_dir_odd);
 }
