@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -62,6 +62,8 @@
 
 #define LW6KER_HISTORY_SIZE 512
 
+#define LW6KER_ACT_LIMIT 100
+
 #include "ker-trigo.h"
 
 typedef struct lw6ker_zone_struct_s
@@ -69,6 +71,8 @@ typedef struct lw6ker_zone_struct_s
   lw6sys_xyz_t pos;
   u_int32_t size;
   int32_t link[LW6KER_NB_DIRS];
+  int16_t one_way_dir_odd;
+  int16_t one_way_dir_even;
 }
 lw6ker_zone_struct_t;
 
@@ -78,6 +82,14 @@ typedef struct lw6ker_slot_struct_s
 }
 lw6ker_slot_struct_t;
 
+typedef struct lw6ker_place_struct_s
+{
+  int32_t act_incr:12;
+  int32_t pad:4;		// free for later use
+  int32_t health_correction:16;
+}
+lw6ker_place_struct_t;
+
 /*
  * To some extent, this structure is very similar to lw6map_level_t.
  * Let's explain why it exists separately: 
@@ -96,12 +108,13 @@ lw6ker_slot_struct_t;
 typedef struct lw6ker_map_struct_s
 {
   lw6sys_whd_t shape;
-  int32_t shape_surface;
+  int32_t nb_places;
   int32_t nb_zones;
   int32_t nb_slots;
   int32_t nb_usable_slots;
   int32_t room_for_armies;
   int32_t max_zone_size;
+  lw6ker_place_struct_t *places;
   lw6ker_zone_struct_t *zones;
   lw6ker_slot_struct_t *slots;
 }
@@ -143,6 +156,8 @@ typedef struct lw6ker_fighter_s
   u_int32_t team_color:8;
   int32_t last_direction:8;
   int32_t health:16;
+  int32_t act_counter:16;
+  int32_t pad:16;		// free for later use
   lw6sys_xyz_t pos;
 }
 lw6ker_fighter_t;
@@ -494,16 +509,17 @@ lw6ker_map_state_set_fighter_id (lw6ker_map_state_t * map_state,
 				 int32_t x,
 				 int32_t y, int32_t z, int32_t fighter_id)
 {
-  map_state->slots[lw6ker_map_state_slot_index (map_state, x, y, z)].
-    fighter_id = fighter_id;
+  map_state->
+    slots[lw6ker_map_state_slot_index (map_state, x, y, z)].fighter_id =
+    fighter_id;
 };
 
 static inline int32_t
 lw6ker_map_state_get_fighter_id (lw6ker_map_state_t * map_state,
 				 int32_t x, int32_t y, int32_t z)
 {
-  return (map_state->slots[lw6ker_map_state_slot_index (map_state, x, y, z)].
-	  fighter_id);
+  return (map_state->
+	  slots[lw6ker_map_state_slot_index (map_state, x, y, z)].fighter_id);
 };
 
 extern lw6ker_fighter_t *lw6ker_map_state_get_fighter_safe (lw6ker_map_state_t
@@ -547,7 +563,7 @@ static inline int
 lw6ker_map_struct_slot_index (lw6ker_map_struct_t * map_struct, int32_t x,
 			      int32_t y, int32_t z)
 {
-  return (map_struct->shape_surface * z + map_struct->shape.w * y + x);
+  return (map_struct->nb_places * z + map_struct->shape.w * y + x);
 }
 
 static inline void
@@ -555,8 +571,9 @@ lw6ker_map_struct_set_zone_id (lw6ker_map_struct_t * map_struct,
 			       int32_t x, int32_t y, int32_t z,
 			       int32_t zone_id)
 {
-  map_struct->slots[lw6ker_map_struct_slot_index (map_struct, x, y, z)].
-    zone_id = zone_id;
+  map_struct->
+    slots[lw6ker_map_struct_slot_index (map_struct, x, y, z)].zone_id =
+    zone_id;
 };
 
 static inline int32_t
@@ -573,6 +590,16 @@ extern void lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t *
 						   lw6sys_xyz_t here);
 extern int lw6ker_map_struct_sanity_check (lw6ker_map_struct_t * map_struct);
 
+/*
+ * in placestruct.c
+ */
+static inline int
+lw6ker_map_struct_place_index (lw6ker_map_struct_t * map_struct, int32_t x,
+			       int32_t y)
+{
+  return (map_struct->shape.w * y + x);
+}
+
 /*
  * in scorearrqy.c
  */
@@ -620,10 +647,8 @@ extern void lw6ker_team_mask_best (u_int32_t * even, u_int32_t * odd,
 extern int lw6ker_team_mask_is_concerned (int team_color,
 					  u_int32_t team_mask);
 
-/*
- * In test.c
- */
-extern int lw6ker_test ();
+/* ker-test.c */
+extern int lw6ker_test (int mode);
 
 /*
  * In trigo.c
