@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -217,3 +217,44 @@ _lw6ldr_bw_clear (_lw6ldr_image_bw_t * image)
 
   memset (image, 0, sizeof (_lw6ldr_image_bw_t));
 }
+
+float
+_lw6ldr_bw_gray_level (_lw6ldr_image_bw_t * image)
+{
+  int x, y, w, h;
+  float ret = 0.0f;
+  int gray_count = 0;
+  u_int8_t *row;
+  u_int32_t c;
+
+  w = image->w;
+  h = image->h;
+  if (w > 0 && h > 0)
+    {
+      for (y = 0; y < h; ++y)
+	{
+	  row = image->data[y];
+	  for (x = 0; x < w; ++x)
+	    {
+	      c = row[x];
+	      gray_count += c >> 6;
+	    }
+	}
+      gray_count = gray_count >> 2;
+
+      ret = ((float) gray_count) / (((float) w) * ((float) h));
+    }
+  if (ret > 1.0f)
+    {
+      ret = 1.0f;
+      lw6sys_log (LW6SYS_LOG_WARNING, _("gray_level=%f, can't be >1"), ret);
+    }
+  if (ret < 0.0f)
+    {
+      ret = 0.0f;
+      lw6sys_log (LW6SYS_LOG_WARNING, _("gray_level=%f, can't be <0"), ret);
+    }
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("gray_level=%f"), ret);
+
+  return ret;
+}
