@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,12 +47,23 @@ lw6ldr_hints_defaults (lw6ldr_hints_t * hints)
   hints->min_map_surface = LW6LDR_HINTS_DEFAULT_MIN_MAP_SURFACE;
   hints->max_map_surface = LW6LDR_HINTS_DEFAULT_MAX_MAP_SURFACE;
   hints->fighter_scale = LW6LDR_HINTS_DEFAULT_FIGHTER_SCALE;
+  hints->downsize_using_fighter_scale =
+    LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_FIGHTER_SCALE;
+  hints->upsize_using_fighter_scale =
+    LW6LDR_HINTS_DEFAULT_UPSIZE_USING_FIGHTER_SCALE;
+  hints->downsize_using_bench_value =
+    LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_BENCH_VALUE;
+  hints->upsize_using_bench_value =
+    LW6LDR_HINTS_DEFAULT_UPSIZE_USING_BENCH_VALUE;
   hints->guess_colors = LW6LDR_HINTS_DEFAULT_GUESS_COLORS;
   hints->background_color_auto = LW6LDR_HINTS_DEFAULT_BACKGROUND_COLOR_AUTO;
   hints->hud_color_auto = LW6LDR_HINTS_DEFAULT_HUD_COLOR_AUTO;
   hints->menu_color_auto = LW6LDR_HINTS_DEFAULT_MENU_COLOR_AUTO;
   hints->view_color_auto = LW6LDR_HINTS_DEFAULT_VIEW_COLOR_AUTO;
   hints->system_color_auto = LW6LDR_HINTS_DEFAULT_SYSTEM_COLOR_AUTO;
+  hints->wall_grease = LW6LDR_HINTS_DEFAULT_WALL_GREASE;
+  hints->guess_moves_per_sec = LW6LDR_HINTS_DEFAULT_GUESS_MOVES_PER_SEC;
+  hints->speed = LW6LDR_HINTS_DEFAULT_SPEED;
 }
 
 void
@@ -173,6 +184,22 @@ lw6ldr_hints_set (lw6ldr_hints_t * hints, char *key, char *value)
 	{
 	  hints->fighter_scale = lw6sys_atof (value);
 	}
+      else if (!strcmp (LW6DEF_DOWNSIZE_USING_FIGHTER_SCALE, formatted_key))
+	{
+	  hints->downsize_using_fighter_scale = lw6sys_atob (value);
+	}
+      else if (!strcmp (LW6DEF_UPSIZE_USING_FIGHTER_SCALE, formatted_key))
+	{
+	  hints->upsize_using_fighter_scale = lw6sys_atob (value);
+	}
+      else if (!strcmp (LW6DEF_DOWNSIZE_USING_BENCH_VALUE, formatted_key))
+	{
+	  hints->downsize_using_bench_value = lw6sys_atob (value);
+	}
+      else if (!strcmp (LW6DEF_UPSIZE_USING_BENCH_VALUE, formatted_key))
+	{
+	  hints->upsize_using_bench_value = lw6sys_atob (value);
+	}
       else if (!strcmp (LW6DEF_GUESS_COLORS, formatted_key))
 	{
 	  hints->guess_colors = lw6sys_atob (value);
@@ -197,6 +224,18 @@ lw6ldr_hints_set (lw6ldr_hints_t * hints, char *key, char *value)
 	{
 	  hints->system_color_auto = lw6sys_atob (value);
 	}
+      else if (!strcmp (LW6DEF_WALL_GREASE, formatted_key))
+	{
+	  hints->wall_grease = lw6sys_atoi (value);
+	}
+      else if (!strcmp (LW6DEF_GUESS_MOVES_PER_SEC, formatted_key))
+	{
+	  hints->guess_moves_per_sec = lw6sys_atob (value);
+	}
+      else if (!strcmp (LW6DEF_SPEED, formatted_key))
+	{
+	  hints->speed = lw6sys_atof (value);
+	}
       else
 	{
 	  ret = 0;
@@ -252,6 +291,22 @@ lw6ldr_hints_get (lw6ldr_hints_t * hints, char *key)
 	{
 	  ret = lw6sys_ftoa (hints->fighter_scale);
 	}
+      else if (!strcmp (LW6DEF_DOWNSIZE_USING_FIGHTER_SCALE, formatted_key))
+	{
+	  ret = lw6sys_btoa (hints->downsize_using_fighter_scale);
+	}
+      else if (!strcmp (LW6DEF_UPSIZE_USING_FIGHTER_SCALE, formatted_key))
+	{
+	  ret = lw6sys_btoa (hints->upsize_using_fighter_scale);
+	}
+      else if (!strcmp (LW6DEF_DOWNSIZE_USING_BENCH_VALUE, formatted_key))
+	{
+	  ret = lw6sys_btoa (hints->downsize_using_bench_value);
+	}
+      else if (!strcmp (LW6DEF_UPSIZE_USING_BENCH_VALUE, formatted_key))
+	{
+	  ret = lw6sys_btoa (hints->upsize_using_bench_value);
+	}
       else if (!strcmp (LW6DEF_GUESS_COLORS, formatted_key))
 	{
 	  ret = lw6sys_btoa (hints->guess_colors);
@@ -276,6 +331,18 @@ lw6ldr_hints_get (lw6ldr_hints_t * hints, char *key)
 	{
 	  ret = lw6sys_btoa (hints->system_color_auto);
 	}
+      else if (!strcmp (LW6DEF_WALL_GREASE, formatted_key))
+	{
+	  ret = lw6sys_itoa (hints->wall_grease);
+	}
+      else if (!strcmp (LW6DEF_GUESS_MOVES_PER_SEC, formatted_key))
+	{
+	  ret = lw6sys_btoa (hints->guess_moves_per_sec);
+	}
+      else if (!strcmp (LW6DEF_SPEED, formatted_key))
+	{
+	  ret = lw6sys_ftoa (hints->speed);
+	}
       LW6SYS_FREE (formatted_key);
     }
 
