@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -282,7 +282,7 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
 	      ret = 1;
 	      break;
 
-	    case 1:		// greyscale
+	    case 1:		// grayscale
 	      row_stride = cinfo.output_width * cinfo.output_components;
 	      buffer = (*cinfo.mem->alloc_sarray)
 		((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
