@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 #include "ldr.h"
 
-#define TEST_MAP "strange-new-world/"
+#define TEST_MAP "subflower/"
 #define TEST_ARGC 2
 #define TEST_ARGV0 "prog"
 #define TEST_ARGV1 "--arg=X"
@@ -64,7 +64,8 @@ check_map_with_absolute_path (char *absolute_path)
   lw6sys_log (LW6SYS_LOG_NOTICE, _("deep check \"%s\""), absolute_path);
   level1 =
     lw6ldr_read (absolute_path, NULL, NULL, TEST_DISPLAY_WIDTH,
-		 TEST_DISPLAY_HEIGHT, NULL);
+		 TEST_DISPLAY_HEIGHT, LW6LDR_DEFAULT_BENCH_VALUE,
+		 LW6LDR_DEFAULT_MAGIC_NUMBER, NULL);
   if (level1)
     {
       hexa_level1 = lw6map_to_hexa (level1);
@@ -372,7 +373,8 @@ test_read ()
 	level =
 	  lw6ldr_read_relative (map_path, TEST_MAP, NULL, NULL,
 				TEST_DISPLAY_WIDTH, TEST_DISPLAY_HEIGHT,
-				&progress);
+				LW6LDR_DEFAULT_BENCH_VALUE,
+				LW6LDR_DEFAULT_MAGIC_NUMBER, &progress);
 	if (level)
 	  {
 	    repr = lw6map_repr (level);
@@ -405,8 +407,17 @@ test_read ()
   return ret;
 }
 
+/**
+ * lw6ldr_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @ldr module test suite.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6ldr_test ()
+lw6ldr_test (int mode)
 {
   int ret = 0;
 
@@ -415,10 +426,10 @@ lw6ldr_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6hlp_test ();
-      lw6cfg_test ();
-      lw6map_test ();
+      lw6sys_test (mode);
+      lw6hlp_test (mode);
+      lw6cfg_test (mode);
+      lw6map_test (mode);
     }
 
   ret = test_dir () && test_hints () && test_param () && test_read ()
