@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,20 +28,38 @@
 #include "../cfg/cfg.h"
 #include "../hlp/hlp.h"
 
+#define LW6LDR_DEFAULT_BENCH_VALUE 20
+/*
+ * This is a "Markov prime" 
+ * http://en.wikipedia.org/wiki/List_of_prime_numbers
+ */
+#define LW6LDR_DEFAULT_MAGIC_NUMBER 43261
+
 #define LW6LDR_HINTS_DEFAULT_RESAMPLE 1
-#define LW6LDR_HINTS_DEFAULT_MIN_MAP_WIDTH 40
-#define LW6LDR_HINTS_DEFAULT_MAX_MAP_WIDTH 1600
-#define LW6LDR_HINTS_DEFAULT_MIN_MAP_HEIGHT 30
-#define LW6LDR_HINTS_DEFAULT_MAX_MAP_HEIGHT 1200
-#define LW6LDR_HINTS_DEFAULT_MIN_MAP_SURFACE 4800
-#define LW6LDR_HINTS_DEFAULT_MAX_MAP_SURFACE 480000
-#define LW6LDR_HINTS_DEFAULT_FIGHTER_SCALE 4.0
+#define LW6LDR_HINTS_DEFAULT_MIN_MAP_WIDTH 20
+#define LW6LDR_HINTS_DEFAULT_MAX_MAP_WIDTH 4000
+#define LW6LDR_HINTS_DEFAULT_MIN_MAP_HEIGHT 15
+#define LW6LDR_HINTS_DEFAULT_MAX_MAP_HEIGHT 3000
+#define LW6LDR_HINTS_DEFAULT_MIN_MAP_SURFACE 1200
+#define LW6LDR_HINTS_DEFAULT_MAX_MAP_SURFACE 3000000
+#define LW6LDR_HINTS_DEFAULT_FIGHTER_SCALE 1.0
+#define LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_FIGHTER_SCALE 0
+#define LW6LDR_HINTS_DEFAULT_UPSIZE_USING_FIGHTER_SCALE 1
+#define LW6LDR_HINTS_DEFAULT_DOWNSIZE_USING_BENCH_VALUE 1
+#define LW6LDR_HINTS_DEFAULT_UPSIZE_USING_BENCH_VALUE 0
 #define LW6LDR_HINTS_DEFAULT_GUESS_COLORS 1
 #define LW6LDR_HINTS_DEFAULT_BACKGROUND_COLOR_AUTO 1
 #define LW6LDR_HINTS_DEFAULT_HUD_COLOR_AUTO 1
 #define LW6LDR_HINTS_DEFAULT_MENU_COLOR_AUTO 1
 #define LW6LDR_HINTS_DEFAULT_VIEW_COLOR_AUTO 1
 #define LW6LDR_HINTS_DEFAULT_SYSTEM_COLOR_AUTO 1
+#define LW6LDR_HINTS_DEFAULT_WALL_GREASE 0
+#define LW6LDR_HINTS_DEFAULT_GUESS_MOVES_PER_SEC 1
+#define LW6LDR_HINTS_DEFAULT_SPEED 1.0
+
+#define LW6LDR_HINTS_MIN_WALL_GREASE -5
+
+#define LW6LDR_HINTS_MAX_WALL_GREASE 5
 
 typedef struct lw6ldr_hints_s
 {
@@ -53,12 +71,19 @@ typedef struct lw6ldr_hints_s
   int min_map_surface;
   int max_map_surface;
   float fighter_scale;
+  int downsize_using_fighter_scale;
+  int upsize_using_fighter_scale;
+  int downsize_using_bench_value;
+  int upsize_using_bench_value;
   int guess_colors;
   int background_color_auto;
   int hud_color_auto;
   int menu_color_auto;
   int view_color_auto;
   int system_color_auto;
+  int wall_grease;
+  int guess_moves_per_sec;
+  float speed;
 } lw6ldr_hints_t;
 
 #define LW6LDR_USE_DEFAULT_USE_TEXTURE 1
@@ -98,6 +123,7 @@ lw6ldr_entry_t;
 extern int lw6ldr_body_read (lw6map_body_t * body, char *dirname,
 			     lw6map_param_t * param, lw6ldr_hints_t * hints,
 			     int display_w, int display_h, float ratio,
+			     int bench_value, int magic_number,
 			     lw6sys_progress_t * progress);
 
 /* ldr-color.c */
@@ -113,6 +139,12 @@ extern void lw6ldr_for_all_entries (char *map_path, char *relative_path,
 				    lw6sys_list_callback_func_t callback_func,
 				    void *func_data);
 
+/* ldr-grease.c */
+extern int lw6ldr_grease_apply (lw6map_layer_t * layer,
+				lw6map_rules_t * rules,
+				lw6ldr_hints_t * hints,
+				lw6sys_progress_t * progress);
+
 /*
  * hints.c
  */
@@ -132,6 +164,9 @@ extern int lw6ldr_layer_read_first (lw6map_layer_t * layer, char *filename,
 				    int display_w,
 				    int display_h,
 				    float target_ratio,
+				    int bench_value,
+				    int magic_number,
+				    int expected_depth,
 				    lw6sys_progress_t * progress);
 extern int lw6ldr_layer_read_next (lw6map_layer_t * layer, char *filename,
 				   int target_w, int target_h);
@@ -141,6 +176,15 @@ extern int lw6ldr_layer_read_next (lw6map_layer_t * layer, char *filename,
  */
 extern int lw6ldr_metadata_read (lw6map_metadata_t * metadata, char *dirname);
 
+/* ldr-metalayer.c */
+extern int lw6ldr_meta_layer_read (lw6map_meta_layer_t * meta_layer,
+				   char *filename, int target_w,
+				   int target_h, int analog);
+extern int lw6ldr_meta_layer_read_if_exists (lw6map_meta_layer_t * meta_layer,
+					     char *dirname, char *file_only,
+					     int target_w, int target_h,
+					     int analog);
+
 /* ldr-rules.c */
 extern int lw6ldr_rules_read (lw6map_rules_t * rules, char *dirname);
 extern int lw6ldr_rules_update (lw6map_rules_t * rules,
@@ -162,12 +206,15 @@ extern lw6map_level_t *lw6ldr_read (char *dirname,
 				    lw6sys_assoc_t * default_param,
 				    lw6sys_assoc_t * forced_param,
 				    int display_w, int display_h,
+				    int bench_value, int magic_number,
 				    lw6sys_progress_t * progress);
 extern lw6map_level_t *lw6ldr_read_relative (char *map_path,
 					     char *relative_path,
 					     lw6sys_assoc_t * default_param,
 					     lw6sys_assoc_t * forced_param,
 					     int display_w, int display_h,
+					     int bench_value,
+					     int magic_number,
 					     lw6sys_progress_t * progress);
 
 /*
@@ -179,10 +226,12 @@ extern void lw6ldr_resampler_init (lw6ldr_resampler_t * resampler,
 				   int source_w,
 				   int source_h,
 				   int display_w,
-				   int display_h, float target_ratio);
+				   int display_h, float target_ratio,
+				   int bench_value, int magic_number,
+				   int expected_depth, float gray_level);
 extern void lw6ldr_resampler_force (lw6ldr_resampler_t * resampler,
-				    int source_w,
-				    int source_h, int target_w, int target_h);
+				    int source_w, int source_h, int target_w,
+				    int target_h);
 extern void lw6ldr_resampler_source2target (lw6ldr_resampler_t * resampler,
 					    int *target_x, int *target_y,
 					    int source_x, int source_y);
@@ -195,10 +244,8 @@ extern int lw6ldr_style_read (lw6map_style_t * style, char *dirname);
 extern int lw6ldr_style_update (lw6map_style_t * style,
 				lw6sys_assoc_t * values);
 
-/*
- * In test.c
- */
-extern int lw6ldr_test ();
+/* ldr-test.c */
+extern int lw6ldr_test (int mode);
 
 /*
  * In texture.c
