@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
  * This is the main Liquid War 6 header file.
  */
 
-#define LW6_VERSION "0.0.7beta"
+#define LW6_VERSION "0.0.8beta"
 
 #include <pthread.h>
 #include <libguile.h>
@@ -65,6 +65,7 @@ typedef struct lw6_smob_types_s
   scm_t_bits bot;
   scm_t_bits look;
   scm_t_bits loader;
+  scm_t_bits node;
 }
 lw6_smob_types_t;
 
@@ -136,6 +137,12 @@ typedef struct lw6_loader_smob_s
 }
 lw6_loader_smob_t;
 
+typedef struct lw6_node_smob_s
+{
+  lw6p2p_node_t *c_node;
+}
+lw6_node_smob_t;
+
 typedef struct lw6_global_s
 {
   pthread_mutex_t mutex;
@@ -158,6 +165,7 @@ typedef struct lw6_global_s
   lw6sys_assoc_t *bot_smobs;
   lw6sys_assoc_t *look_smobs;
   lw6sys_assoc_t *loader_smobs;
+  lw6sys_assoc_t *node_smobs;
 }
 lw6_global_t;
 
@@ -209,7 +217,7 @@ extern void lw6_print_short_copyright ();
 extern void lw6_print_long_copyright ();
 extern void lw6_print_bench (float bench_result);
 extern void lw6_print_pedigree ();
-extern void lw6_print_target ();
+extern void lw6_print_host ();
 extern void lw6_print_audit (int argc, char *argv[]);
 extern void lw6_print_modules ();
 extern void lw6_print_list_quick ();
@@ -272,11 +280,12 @@ extern void lw6_free_look_smob (lw6_look_smob_t * look_smob);
 extern SCM lw6_make_scm_loader (lw6tsk_loader_t * c_loader);
 extern lw6tsk_loader_t *lw6_scm_to_loader (SCM loader);
 extern void lw6_free_loader_smob (lw6_loader_smob_t * loader_smob);
+extern SCM lw6_make_scm_node (lw6p2p_node_t * c_node);
+extern lw6p2p_node_t *lw6_scm_to_node (SCM node);
+extern void lw6_free_node_smob (lw6_node_smob_t * node_smob);
 extern int lw6_register_smobs ();
 
-/*
- * Functions in test.c
- */
-extern int lw6_test ();
+/* lw6-test.c */
+extern int lw6_test (int mode);
 
 #endif
