@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -86,7 +86,9 @@ lw6_init_global (int argc, char *argv[])
       lw6sys_assoc_new ((void (*)(void *)) lw6_free_look_smob)) != NULL)
     &&
     ((lw6_global.loader_smobs =
-      lw6sys_assoc_new ((void (*)(void *)) lw6_free_loader_smob)) != NULL);
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_loader_smob)) != NULL) &&
+    ((lw6_global.node_smobs =
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_node_smob)) != NULL);
 
   LW6_MUTEX_UNLOCK;
 
@@ -145,6 +147,8 @@ lw6_quit_global_2 ()
    * Should the Guile GC be perfect, not one single object
    * would be freed here.
    */
+  lw6sys_assoc_free (lw6_global.node_smobs);
+  lw6_global.node_smobs = NULL;
   lw6sys_assoc_free (lw6_global.loader_smobs);
   lw6_global.loader_smobs = NULL;
   lw6sys_assoc_free (lw6_global.look_smobs);
