@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #ifdef LW6_ALLINONE
 #define DYN_TEST 1
 #else
-#define DYN_TEST lw6dyn_test()
+#define DYN_TEST lw6dyn_test(1)
 #endif
 
 int
@@ -120,15 +120,35 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	      LW6SYS_FREE (log_file);
 	    }
 
-	  ret = lw6sys_test ()
-	    && lw6map_test ()
-	    && lw6ker_test () && DYN_TEST && lw6bot_test ()
-	    && lw6cns_test ()
-	    && lw6hlp_test () && lw6cfg_test () && lw6ldr_test ()
-	    && lw6tsk_test () && lw6gui_test () && lw6gfx_test ()
-	    && lw6dsp_test () && lw6snd_test () && lw6img_test ()
-	    && lw6pil_test () && lw6net_test () && lw6cli_test ()
-	    && lw6srv_test () && lw6p2p_test () && lw6_test ();
+	  ret = lw6sys_test (1)
+	    && lw6map_test (1)
+	    && lw6ker_test (1) && DYN_TEST && lw6bot_test (1)
+	    && lw6cns_test (1)
+	    && lw6hlp_test (1) && lw6cfg_test (1) && lw6ldr_test (1)
+	    && lw6tsk_test (1) && lw6gui_test (1) && lw6gfx_test (1)
+	    && lw6dsp_test (1) && lw6snd_test (1) && lw6img_test (1)
+	    && lw6pil_test (1) && lw6net_test (1) && lw6cli_test (1)
+	    && lw6srv_test (1) && lw6p2p_test (1) && lw6_test (1);
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_CHECK, argv[i]))
+	{
+	  log_file = lw6cfg_unified_get_log_file (argc, argv);
+	  if (log_file)
+	    {
+	      lw6sys_log_clear (log_file);
+	      LW6SYS_FREE (log_file);
+	    }
+
+	  ret = lw6sys_test (0)
+	    && lw6map_test (0)
+	    && lw6ker_test (0) && DYN_TEST && lw6bot_test (0)
+	    && lw6cns_test (0)
+	    && lw6hlp_test (0) && lw6cfg_test (0) && lw6ldr_test (0)
+	    && lw6tsk_test (0) && lw6gui_test (0) && lw6gfx_test (0)
+	    && lw6dsp_test (0) && lw6snd_test (0) && lw6img_test (0)
+	    && lw6pil_test (0) && lw6net_test (0) && lw6cli_test (0)
+	    && lw6srv_test (0) && lw6p2p_test (0) && lw6_test (0);
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_BENCH, argv[i]))
@@ -136,7 +156,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  float bench_result = 0.0f;
 
 	  lw6sys_log_clear (NULL);
-	  ret = lw6pil_bench (&bench_result);
+	  ret = lw6pil_bench (&bench_result, NULL);
 	  lw6_print_bench (bench_result);
 
 	  (*run_game) = 0;
@@ -155,9 +175,9 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6_print_pedigree ();
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_TARGET, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_HOST, argv[i]))
 	{
-	  lw6_print_target ();
+	  lw6_print_host ();
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_AUDIT, argv[i]))
@@ -336,6 +356,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_license ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_URL, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_url ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_CONFIGURE_ARGS, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_configure_args ());
@@ -373,9 +398,9 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_time ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_TARGET_CPU, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_HOST_CPU, argv[i]))
 	{
-	  printf ("%s\n", lw6sys_build_get_target_cpu ());
+	  printf ("%s\n", lw6sys_build_get_host_cpu ());
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENDIANNESS, argv[i]))
@@ -393,9 +418,9 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%d\n", lw6sys_build_is_x86 ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_TARGET_OS, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_HOST_OS, argv[i]))
 	{
-	  printf ("%s\n", lw6sys_build_get_target_os ());
+	  printf ("%s\n", lw6sys_build_get_host_os ());
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_MS_WINDOWS, argv[i]))
@@ -403,6 +428,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%d\n", lw6sys_build_is_ms_windows ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_GP2X, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_is_gp2x ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_MAC_OS_X, argv[i]))
 	{
 	  printf ("%d\n", lw6sys_build_is_mac_os_x ());
@@ -516,6 +546,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_enable_valgrind ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_BIN_ID, argv[i]))
+	{
+	  printf ("%d\n", lw6sys_build_get_bin_id ());
+	  (*run_game) = 0;
+	}
       /*
        * Show any interesting default path
        */
@@ -585,6 +620,28 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	    }
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_DEFAULT_MUSIC_DIR, argv[i]))
+	{
+	  path = lw6sys_get_default_music_dir ();
+	  if (path)
+	    {
+	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
+	      path = NULL;
+	    }
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_DEFAULT_MUSIC_PATH, argv[i]))
+	{
+	  path = lw6sys_get_default_music_path ();
+	  if (path)
+	    {
+	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
+	      path = NULL;
+	    }
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_DEFAULT_MAP_DIR, argv[i]))
 	{
 	  path = lw6sys_get_default_map_dir ();
@@ -709,6 +766,28 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	    }
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_MUSIC_DIR, argv[i]))
+	{
+	  path = lw6sys_get_music_dir (argc, argv);
+	  if (path)
+	    {
+	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
+	      path = NULL;
+	    }
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_MUSIC_PATH, argv[i]))
+	{
+	  path = lw6cfg_unified_get_music_path (argc, argv);
+	  if (path)
+	    {
+	      printf ("%s\n", path);
+	      LW6SYS_FREE (path);
+	      path = NULL;
+	    }
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_MAP_DIR, argv[i]))
 	{
 	  path = lw6sys_get_map_dir (argc, argv);
