@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #define SMOB_TYPE_BOT "lw6bot-backend"
 #define SMOB_TYPE_LOOK "lw6gui-look"
 #define SMOB_TYPE_LOADER "lw6tsk-loader"
+#define SMOB_TYPE_NODE "lw6p2p-node"
 
 static char *
 smob_id (char *type, int id)
@@ -1346,6 +1347,131 @@ lw6_free_loader_smob (lw6_loader_smob_t * loader_smob)
   LW6SYS_FREE (loader_smob);
 }
 
+/*
+ * Node smob
+ */
+static SCM
+mark_node (SCM node)
+{
+  return SCM_BOOL_F;
+}
+
+static size_t
+free_node (SCM node)
+{
+  char *id = NULL;
+  lw6_node_smob_t *node_smob = (lw6_node_smob_t *) SCM_SMOB_DATA (node);
+
+  LW6_MUTEX_LOCK;
+
+  lw6sys_log (LW6SYS_LOG_INFO, _("garbage collect node smob"));
+  id = smob_id (SMOB_TYPE_NODE, node_smob->c_node->id);
+  if (id)
+    {
+      if (lw6_global.node_smobs)
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("request free node smob \"%s\""),
+		      id);
+	  lw6sys_assoc_unset (lw6_global.node_smobs, id);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("request free node smob \"%s\" but assoc is NULL"),
+		      id);
+	}
+      LW6SYS_FREE (id);
+    }
+
+  LW6_MUTEX_UNLOCK;
+
+  return 0;
+}
+
+static int
+print_node (SCM node, SCM port, scm_print_state * pstate)
+{
+  lw6p2p_node_t *c_node = lw6_scm_to_node (node);
+  char *repr = NULL;
+
+  repr = lw6p2p_node_repr (c_node);
+
+  scm_puts ("#<" SMOB_TYPE_NODE " ", port);
+  if (repr)
+    {
+      scm_display (scm_makfrom0str (repr), port);
+      LW6SYS_FREE (repr);
+    }
+  scm_puts (">", port);
+
+  return 1;
+}
+
+SCM
+lw6_make_scm_node (lw6p2p_node_t * c_node)
+{
+  char *repr = NULL;
+  char *id = NULL;
+  lw6_node_smob_t *node_smob = NULL;
+
+  scm_gc ();
+
+  node_smob = (lw6_node_smob_t *) LW6SYS_CALLOC (sizeof (lw6_node_smob_t));
+  if (node_smob)
+    {
+      node_smob->c_node = c_node;
+      id = smob_id (SMOB_TYPE_NODE, c_node->id);
+      if (id)
+	{
+	  repr = lw6p2p_node_repr (c_node);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating node smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.node_smobs, id,
+				(void *) node_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to create node smob, expect trouble"));
+    }
+
+  SCM_RETURN_NEWSMOB (lw6_global.smob_types.node, node_smob);
+}
+
+lw6p2p_node_t *
+lw6_scm_to_node (SCM node)
+{
+  void *c_node;
+
+  c_node = ((lw6_node_smob_t *) SCM_SMOB_DATA (node))->c_node;
+
+  return c_node;
+}
+
+void
+lw6_free_node_smob (lw6_node_smob_t * node_smob)
+{
+  char *repr = NULL;
+
+  repr = lw6p2p_node_repr (node_smob->c_node);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("freeing node smob \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+
+  lw6p2p_node_free (node_smob->c_node);
+  LW6SYS_FREE (node_smob);
+}
+
 /*
  * Register all the smobs, that is new types.
  */
@@ -1415,5 +1541,11 @@ lw6_register_smobs ()
   scm_set_smob_free (lw6_global.smob_types.loader, free_loader);
   scm_set_smob_print (lw6_global.smob_types.loader, print_loader);
 
+  lw6_global.smob_types.node =
+    scm_make_smob_type (SMOB_TYPE_NODE, sizeof (lw6_node_smob_t));
+  scm_set_smob_mark (lw6_global.smob_types.node, mark_node);
+  scm_set_smob_free (lw6_global.smob_types.node, free_node);
+  scm_set_smob_print (lw6_global.smob_types.node, print_node);
+
   return ret;
 }
