@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,14 +32,22 @@
 #define TEST_ARGC 1
 #define TEST_ARGV0 "prog"
 
+typedef struct _lw6_test_param_s
+{
+  int ret;
+}
+_lw6_test_param_t;
+
 static char *
 get_test_file ()
 {
+  int argc = TEST_ARGC;
+  char *argv[] = { TEST_ARGV0 };
   char *script_file = NULL;
   char *script_dir = NULL;
   char *ret = NULL;
 
-  script_file = lw6sys_get_default_script_file ();
+  script_file = lw6sys_get_script_file (argc, argv);
   if (script_file)
     {
       script_dir = lw6sys_path_parent (script_file);
@@ -51,13 +59,20 @@ get_test_file ()
       LW6SYS_FREE (script_file);
     }
 
+  if (ret && !lw6sys_file_exists (ret))
+    {
+      LW6SYS_FREE (ret);
+      ret = NULL;
+    }
+
   return ret;
 }
 
-static int
-test_callback ()
+static void
+test_callback (_lw6_test_param_t * param)
 {
   int ret = 1;
+
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
@@ -98,30 +113,45 @@ test_callback ()
   }
 
   LW6SYS_TEST_FUNCTION_END;
-  return ret;
+
+  param->ret = ret;
 }
 
 static void *
 guile_test (void *data)
 {
-  int *ret = (int *) data;
+  _lw6_test_param_t *param = (_lw6_test_param_t *) data;
 
-  (*ret) = test_callback ();
+  test_callback (param);
 
   return NULL;
 }
 
+/**
+ * lw6_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the liquidwar6 core module test suite, this will mostly
+ * test how Guile script integration works, loading a sample
+ * script and running it. It does not launch all the other sub
+ * modules tests.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6_test ()
+lw6_test (int mode)
 {
-  int ret = 0;
+  _lw6_test_param_t param;
   int argc = TEST_ARGC;
-  char *argv[TEST_ARGC] = { TEST_ARGV0 };
+  char *argv[] = { TEST_ARGV0 };
+
+  memset (&param, 0, sizeof (_lw6_test_param_t));
 
   if (lw6_init_global (argc, argv))
     {
-      scm_with_guile (guile_test, &ret);
+      scm_with_guile (guile_test, &param);
     }
 
-  return ret;
+  return param.ret;
 }
