@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ main (int argc, char *argv[])
   LW6HLP_MAIN_BEGIN;
 
   lw6sys_log_clear (NULL);
-  ret = lw6_test ();
+  ret = lw6_test (lw6sys_arg_test_mode (argc, argv));
 
   LW6HLP_MAIN_END;
   LW6SYS_MAIN_END;
