@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 char *LW6MAP_RULES_LIST[] = {
   LW6DEF_TOTAL_TIME,
   LW6DEF_RESPAWN_TEAM,
+  LW6DEF_RESPAWN_RANDOM_PLACE,
   LW6DEF_MOVES_PER_ROUND,
   LW6DEF_SPREADS_PER_ROUND,
   LW6DEF_ROUNDS_PER_SEC,
@@ -81,12 +82,17 @@ char *LW6MAP_RULES_LIST[] = {
   LW6DEF_START_POSITION_MODE,
   LW6DEF_COLOR_CONFLICT_MODE,
   LW6DEF_SPREAD_THREAD,
+  LW6DEF_GLUE_POWER,
+  LW6DEF_BOOST_POWER,
+  LW6DEF_DANGER_POWER,
+  LW6DEF_MEDICINE_POWER,
   NULL				// very important that this list is NULL-terminated
 };
 
 static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_TOTAL_TIME,
   LW6MAP_RULES_DEFAULT_RESPAWN_TEAM,
+  LW6MAP_RULES_DEFAULT_RESPAWN_RANDOM_PLACE,
   LW6MAP_RULES_DEFAULT_MOVES_PER_ROUND,
   LW6MAP_RULES_DEFAULT_SPREADS_PER_ROUND,
   LW6MAP_RULES_DEFAULT_ROUNDS_PER_SEC,
@@ -136,12 +142,17 @@ static lw6map_rules_t default_rules = {
   LW6MAP_RULES_DEFAULT_START_PINK_Y,
   LW6MAP_RULES_DEFAULT_START_POSITION_MODE,
   LW6MAP_RULES_DEFAULT_COLOR_CONFLICT_MODE,
-  LW6MAP_RULES_DEFAULT_SPREAD_THREAD
+  LW6MAP_RULES_DEFAULT_SPREAD_THREAD,
+  LW6MAP_RULES_DEFAULT_GLUE_POWER,
+  LW6MAP_RULES_DEFAULT_BOOST_POWER,
+  LW6MAP_RULES_DEFAULT_DANGER_POWER,
+  LW6MAP_RULES_DEFAULT_MEDICINE_POWER
 };
 
 static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_TOTAL_TIME,
   LW6MAP_RULES_MIN_RESPAWN_TEAM,
+  LW6MAP_RULES_MIN_RESPAWN_RANDOM_PLACE,
   LW6MAP_RULES_MIN_MOVES_PER_ROUND,
   LW6MAP_RULES_MIN_SPREADS_PER_ROUND,
   LW6MAP_RULES_MIN_ROUNDS_PER_SEC,
@@ -191,12 +202,17 @@ static lw6map_rules_t min_rules = {
   LW6MAP_RULES_MIN_START_PINK_Y,
   LW6MAP_RULES_MIN_START_POSITION_MODE,
   LW6MAP_RULES_MIN_COLOR_CONFLICT_MODE,
-  LW6MAP_RULES_MIN_SPREAD_THREAD
+  LW6MAP_RULES_MIN_SPREAD_THREAD,
+  LW6MAP_RULES_MIN_GLUE_POWER,
+  LW6MAP_RULES_MIN_BOOST_POWER,
+  LW6MAP_RULES_MIN_DANGER_POWER,
+  LW6MAP_RULES_MIN_MEDICINE_POWER
 };
 
 static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_TOTAL_TIME,
   LW6MAP_RULES_MAX_RESPAWN_TEAM,
+  LW6MAP_RULES_MAX_RESPAWN_RANDOM_PLACE,
   LW6MAP_RULES_MAX_MOVES_PER_ROUND,
   LW6MAP_RULES_MAX_SPREADS_PER_ROUND,
   LW6MAP_RULES_MAX_ROUNDS_PER_SEC,
@@ -246,7 +262,11 @@ static lw6map_rules_t max_rules = {
   LW6MAP_RULES_MAX_START_PINK_Y,
   LW6MAP_RULES_MAX_START_POSITION_MODE,
   LW6MAP_RULES_MAX_COLOR_CONFLICT_MODE,
-  LW6MAP_RULES_MAX_SPREAD_THREAD
+  LW6MAP_RULES_MAX_SPREAD_THREAD,
+  LW6MAP_RULES_MAX_GLUE_POWER,
+  LW6MAP_RULES_MAX_BOOST_POWER,
+  LW6MAP_RULES_MAX_DANGER_POWER,
+  LW6MAP_RULES_MAX_MEDICINE_POWER
 };
 
 void
@@ -270,6 +290,7 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, rules->total_time);
   lw6sys_checksum_update_int32 (checksum, rules->respawn_team);
+  lw6sys_checksum_update_int32 (checksum, rules->respawn_random_place);
   lw6sys_checksum_update_int32 (checksum, rules->moves_per_round);
   lw6sys_checksum_update_int32 (checksum, rules->spreads_per_round);
   lw6sys_checksum_update_int32 (checksum, rules->rounds_per_sec);
@@ -320,6 +341,10 @@ lw6map_rules_update_checksum (lw6map_rules_t * rules, u_int32_t * checksum)
   lw6sys_checksum_update_int32 (checksum, rules->start_position_mode);
   lw6sys_checksum_update_int32 (checksum, rules->color_conflict_mode);
   lw6sys_checksum_update_int32 (checksum, rules->spread_thread);
+  lw6sys_checksum_update_int32 (checksum, rules->glue_power);
+  lw6sys_checksum_update_int32 (checksum, rules->boost_power);
+  lw6sys_checksum_update_int32 (checksum, rules->danger_power);
+  lw6sys_checksum_update_int32 (checksum, rules->medicine_power);
 }
 
 int32_t *
@@ -341,6 +366,10 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->respawn_team);
 	    }
+	  else if (!strcmp (formatted_key, LW6DEF_RESPAWN_RANDOM_PLACE))
+	    {
+	      ret = &(rules->respawn_random_place);
+	    }
 	  else if (!strcmp (formatted_key, LW6DEF_MOVES_PER_ROUND))
 	    {
 	      ret = &(rules->moves_per_round);
@@ -541,6 +570,22 @@ get_rules_int_ptr (lw6map_rules_t * rules, char *key)
 	    {
 	      ret = &(rules->spread_thread);
 	    }
+	  else if (!strcmp (formatted_key, LW6DEF_GLUE_POWER))
+	    {
+	      ret = &(rules->glue_power);
+	    }
+	  else if (!strcmp (formatted_key, LW6DEF_BOOST_POWER))
+	    {
+	      ret = &(rules->boost_power);
+	    }
+	  else if (!strcmp (formatted_key, LW6DEF_DANGER_POWER))
+	    {
+	      ret = &(rules->danger_power);
+	    }
+	  else if (!strcmp (formatted_key, LW6DEF_MEDICINE_POWER))
+	    {
+	      ret = &(rules->medicine_power);
+	    }
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
