@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,9 +45,13 @@
 #define LW6MAP_RULES_MIN_RESPAWN_TEAM 0
 #define LW6MAP_RULES_MAX_RESPAWN_TEAM 1
 
+#define LW6MAP_RULES_DEFAULT_RESPAWN_RANDOM_PLACE 1
+#define LW6MAP_RULES_MIN_RESPAWN_RANDOM_PLACE 0
+#define LW6MAP_RULES_MAX_RESPAWN_RANDOM_PLACE 1
+
 #define LW6MAP_RULES_DEFAULT_MOVES_PER_ROUND 2
 #define LW6MAP_RULES_MIN_MOVES_PER_ROUND 1
-#define LW6MAP_RULES_MAX_MOVES_PER_ROUND 10
+#define LW6MAP_RULES_MAX_MOVES_PER_ROUND 50
 
 #define LW6MAP_RULES_DEFAULT_SPREADS_PER_ROUND 3
 #define LW6MAP_RULES_MIN_SPREADS_PER_ROUND 1
@@ -55,7 +59,7 @@
 
 #define LW6MAP_RULES_DEFAULT_ROUNDS_PER_SEC 50
 #define LW6MAP_RULES_MIN_ROUNDS_PER_SEC 1
-#define LW6MAP_RULES_MAX_ROUNDS_PER_SEC 100
+#define LW6MAP_RULES_MAX_ROUNDS_PER_SEC 200
 
 #define LW6MAP_RULES_DEFAULT_FIGHTER_ATTACK 500
 #define LW6MAP_RULES_MIN_FIGHTER_ATTACK 1
@@ -254,6 +258,22 @@
 #define LW6MAP_RULES_MIN_SPREAD_THREAD 0
 #define LW6MAP_RULES_MAX_SPREAD_THREAD 1
 
+#define LW6MAP_RULES_DEFAULT_GLUE_POWER 20
+#define LW6MAP_RULES_MIN_GLUE_POWER 0
+#define LW6MAP_RULES_MAX_GLUE_POWER 100
+
+#define LW6MAP_RULES_DEFAULT_BOOST_POWER 3
+#define LW6MAP_RULES_MIN_BOOST_POWER 0
+#define LW6MAP_RULES_MAX_BOOST_POWER 10
+
+#define LW6MAP_RULES_DEFAULT_DANGER_POWER 200
+#define LW6MAP_RULES_MIN_DANGER_POWER 0
+#define LW6MAP_RULES_MAX_DANGER_POWER LW6MAP_MAX_FIGHTER_HEALTH
+
+#define LW6MAP_RULES_DEFAULT_MEDICINE_POWER 100
+#define LW6MAP_RULES_MIN_MEDICINE_POWER 0
+#define LW6MAP_RULES_MAX_MEDICINE_POWER LW6MAP_MAX_FIGHTER_HEALTH
+
 /*
  * Note: it's important that floats are never ever used in map rules.
  * In fact, we need maps to be 100,00 (lots of zeroes) predictable,
@@ -267,6 +287,7 @@ typedef struct lw6map_rules_s
 {
   int32_t total_time;
   int32_t respawn_team;
+  int32_t respawn_random_place;
   int32_t moves_per_round;
   int32_t spreads_per_round;
   int32_t rounds_per_sec;
@@ -317,6 +338,10 @@ typedef struct lw6map_rules_s
   int32_t start_position_mode;
   int32_t color_conflict_mode;
   int32_t spread_thread;
+  int32_t glue_power;
+  int32_t boost_power;
+  int32_t danger_power;
+  int32_t medicine_power;
 } lw6map_rules_t;
 extern char *LW6MAP_RULES_LIST[];
 
@@ -369,6 +394,7 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_STYLE_DEFAULT_VIEW_COLOR_MAP_FG "#ccc"
 #define LW6MAP_STYLE_DEFAULT_SYSTEM_COLOR_BG "#333"
 #define LW6MAP_STYLE_DEFAULT_SYSTEM_COLOR_FG "#fff"
+#define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_DEAD "#000"
 #define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_RED "#f00"
 #define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_GREEN "#0f0"
 #define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_BLUE "#00f"
@@ -379,6 +405,14 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_LIGHTBLUE "#8bf"
 #define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_PURPLE "#b8f"
 #define LW6MAP_STYLE_DEFAULT_TEAM_COLOR_PINK "#f8b"
+#define LW6MAP_STYLE_DEFAULT_MUSIC_FILE ""
+#define LW6MAP_STYLE_DEFAULT_MUSIC_FILTER ""
+/*
+ * Hi Tim, this is not to blacklist you, no way! Only this
+ * is needed so that your tunes don't get played *in game*
+ * but only while navigating in the menus.
+ */
+#define LW6MAP_STYLE_DEFAULT_MUSIC_EXCLUDE "Chadburn"
 
 #define LW6MAP_TEAM_COLOR_KEY_RED "red"
 #define LW6MAP_TEAM_COLOR_KEY_GREEN "green"
@@ -396,6 +430,7 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_BUILTIN_DEFAULT_WIDTH 256
 #define LW6MAP_BUILTIN_DEFAULT_HEIGHT 128
 #define LW6MAP_BUILTIN_DEFAULT_DEPTH 1
+#define LW6MAP_BUILTIN_DEFAULT_NOISE_PERCENT 10
 
 typedef enum lw6map_team_color_e
 { LW6MAP_TEAM_COLOR_INVALID = -1, LW6MAP_TEAM_COLOR_RED =
@@ -412,17 +447,44 @@ typedef struct lw6map_metadata_s
   char *readme;
 } lw6map_metadata_t;
 
+/*
+ * Local info is for fields which can be exploited locally,
+ * but make no sense if transfered to another computer, over
+ * the network for instance. This is typically something
+ * which will be updated by the ldr module or some other external
+ * code, but it's not directly linked to the content of the
+ * map itself.
+ */
+typedef struct lw6map_local_info_s
+{
+  char *music_dir;
+} lw6map_local_info_t;
+
 typedef struct lw6map_layer_s
 {
   lw6sys_whd_t shape;
   u_int8_t *data;
 } lw6map_layer_t;
 
+typedef struct lw6map_meta_layer_s
+{
+  lw6sys_whd_t shape;
+  u_int8_t *data;
+} lw6map_meta_layer_t;
+
 typedef struct lw6map_body_s
 {
   int checksum;
   lw6sys_whd_t shape;
   lw6map_layer_t layers[LW6MAP_MAX_DEPTH];
+  lw6map_meta_layer_t glue;
+  lw6map_meta_layer_t boost;
+  lw6map_meta_layer_t danger;
+  lw6map_meta_layer_t medicine;
+  lw6map_meta_layer_t one_way_north;
+  lw6map_meta_layer_t one_way_east;
+  lw6map_meta_layer_t one_way_south;
+  lw6map_meta_layer_t one_way_west;
 } lw6map_body_t;
 
 typedef struct lw6map_color_couple_s
@@ -441,6 +503,24 @@ typedef struct lw6map_texture_s
   lw6map_color_couple_t guessed_color_alternate;
 } lw6map_texture_t;
 
+typedef struct lw6map_color_set_s
+{
+  lw6map_color_couple_t color_base;
+  lw6map_color_couple_t color_alternate;
+  lw6map_color_couple_t background_color_root;
+  lw6map_color_couple_t background_color_stuff;
+  lw6map_color_couple_t hud_color_frame;
+  lw6map_color_couple_t hud_color_text;
+  lw6map_color_couple_t menu_color_default;
+  lw6map_color_couple_t menu_color_selected;
+  lw6map_color_couple_t menu_color_disabled;
+  lw6map_color_couple_t view_color_cursor;
+  lw6map_color_couple_t view_color_map;
+  lw6map_color_couple_t system_color;
+  lw6sys_color_8_t team_color_dead;
+  lw6sys_color_8_t team_colors[LW6MAP_NB_TEAM_COLORS];
+} lw6map_color_set_t;
+
 typedef struct lw6map_style_s
 {
   int keep_ratio;		// boolean
@@ -459,19 +539,10 @@ typedef struct lw6map_style_s
   float hidden_layer_alpha;
   int colorize;
   int pixelize;
-  lw6map_color_couple_t color_base;
-  lw6map_color_couple_t color_alternate;
-  lw6map_color_couple_t background_color_root;
-  lw6map_color_couple_t background_color_stuff;
-  lw6map_color_couple_t hud_color_frame;
-  lw6map_color_couple_t hud_color_text;
-  lw6map_color_couple_t menu_color_default;
-  lw6map_color_couple_t menu_color_selected;
-  lw6map_color_couple_t menu_color_disabled;
-  lw6map_color_couple_t view_color_cursor;
-  lw6map_color_couple_t view_color_map;
-  lw6map_color_couple_t system_color;
-  lw6sys_color_8_t team_colors[LW6MAP_NB_TEAM_COLORS];
+  lw6map_color_set_t color_set;
+  char *music_file;
+  char *music_filter;
+  char *music_exclude;
 } lw6map_style_t;
 
 typedef struct lw6map_param_s
@@ -484,6 +555,7 @@ typedef struct lw6map_level_s
 {
   u_int32_t id;
   lw6map_metadata_t metadata;
+  lw6map_local_info_t local_info;
   lw6map_body_t body;
   lw6map_texture_t texture;
   lw6map_param_t param;
@@ -530,27 +602,10 @@ lw6map_texture_get (lw6map_texture_t * texture, int x, int y)
   return texture->data[y * texture->w + x];
 }
 
-/* map-color.c */
-extern void lw6map_color_invert (lw6map_color_couple_t * color);
-extern int lw6map_color_is_same (lw6map_color_couple_t * color1,
-				 lw6map_color_couple_t * color2);
-extern char *lw6map_team_color_index_to_key (int index);
-extern int lw6map_team_color_key_to_index (char *key);
-
-
-/* map-coords.c */
-extern void lw6map_coords_fix_xy (lw6map_rules_t * rules,
-				  lw6sys_whd_t * shape, int *x, int *y);
-extern void lw6map_coords_fix_z (lw6map_rules_t * rules, lw6sys_whd_t * shape,
-				 int *z);
-
-/* map-dup.c */
-extern lw6map_level_t *lw6map_dup (lw6map_level_t * source,
-				   lw6sys_progress_t * progress);
-
 /* map-body.c */
-extern void lw6map_body_builtin_whd (lw6map_body_t * body, int w, int h,
-				     int d);
+extern void lw6map_body_builtin_custom (lw6map_body_t * body, int w, int h,
+					int d, int noise_percent,
+					lw6map_rules_t * rules);
 extern void lw6map_body_clear (lw6map_body_t * body);
 extern void lw6map_body_fix_checksum (lw6map_body_t * body);
 extern int lw6map_body_check_and_fix_holes (lw6map_body_t * body,
@@ -563,24 +618,49 @@ extern u_int8_t lw6map_body_get_with_texture_coord (lw6map_level_t *
 						    int texture_x,
 						    int texture_y, int z);
 
+/* map-color.c */
+extern void lw6map_color_invert (lw6map_color_couple_t * color);
+extern int lw6map_color_is_same (lw6map_color_couple_t * color1,
+				 lw6map_color_couple_t * color2);
+extern char *lw6map_team_color_index_to_key (int index);
+extern int lw6map_team_color_key_to_index (char *key);
+
+
+/* map-coords.c */
+extern void lw6map_coords_fix_xy (lw6map_rules_t * rules,
+				  lw6sys_whd_t * shape, int *x, int *y);
+extern void lw6map_coords_fix_z (lw6map_rules_t * rules,
+				 lw6sys_whd_t * shape, int *z);
+
+/* map-dup.c */
+extern lw6map_level_t *lw6map_dup (lw6map_level_t * source,
+				   lw6sys_progress_t * progress);
+
 /* map-hexa.c */
 extern char *lw6map_to_hexa (lw6map_level_t * level);
 extern lw6map_level_t *lw6map_from_hexa (char *hexa);
 
 /* map-layer.c */
-extern void lw6map_layer_builtin_whd (lw6map_layer_t * layer, int w, int h);
+extern void lw6map_layer_builtin_custom (lw6map_layer_t * layer, int w,
+					 int h);
 extern void lw6map_layer_clear (lw6map_layer_t * layer);
 
 /* map-level.c */
 extern lw6map_level_t *lw6map_new ();
 extern lw6map_level_t *lw6map_builtin_defaults ();
-extern lw6map_level_t *lw6map_builtin_whd (int w, int h, int d);
+extern lw6map_level_t *lw6map_builtin_custom (int w, int h, int d,
+					      int noise_percent);
 extern void lw6map_free (lw6map_level_t * level);
 extern int lw6map_memory_footprint (lw6map_level_t * level);
 extern char *lw6map_repr (lw6map_level_t * level);
 extern int lw6map_is_same (lw6map_level_t * level_a,
 			   lw6map_level_t * level_b);
 
+/* map-localinfo.c */
+extern int lw6map_local_info_set_music_dir (lw6map_local_info_t *
+					    local_info, char *music_dir);
+extern void lw6map_local_info_clear (lw6map_local_info_t * local_info);
+
 /*
  * In metadata.c
  */
@@ -589,6 +669,16 @@ extern void lw6map_metadata_clear (lw6map_metadata_t * metadata);
 extern int lw6map_metadata_is_same (lw6map_metadata_t * metadata_a,
 				    lw6map_metadata_t * metadata_b);
 
+/* map-metalayer.c */
+extern void lw6map_meta_layer_set (lw6map_meta_layer_t * meta_layer, int x,
+				   int y, u_int8_t value);
+extern u_int8_t lw6map_meta_layer_get (lw6map_meta_layer_t * meta_layer,
+				       int x, int y);
+extern void lw6map_meta_layer_clear (lw6map_meta_layer_t * meta_layer);
+extern int lw6map_meta_layer_builtin_custom (lw6map_meta_layer_t * meta_layer,
+					     int w, int h, int analog,
+					     int noise_percent, int seed);
+
 /*
  * In rules.c
  */
@@ -627,13 +717,13 @@ extern void lw6map_style_copy (lw6map_style_t * dst, lw6map_style_t * src);
 extern int lw6map_style_set (lw6map_style_t * style, char *key, char *value);
 extern char *lw6map_style_get (lw6map_style_t * style, char *key);
 extern char *lw6map_style_get_default (char *key);
+extern int lw6map_color_set_is_same (lw6map_color_set_t * color_set_a,
+				     lw6map_color_set_t * color_set_b);
 extern int lw6map_style_is_same (lw6map_style_t * style_a,
 				 lw6map_style_t * style_b);
 
-/*
- * In test.c
- */
-extern int lw6map_test ();
+/* map-test.c */
+extern int lw6map_test (int mode);
 
 /*
  * In texture.c
