@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -102,7 +102,8 @@ _lw6net_socket_bind (char *ip, int port, int protocol)
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, _("bind() failed"));
+		  lw6sys_log (LW6SYS_LOG_WARNING, _("bind() on %s:%d failed"),
+			      ip, port);
 		  lw6net_last_error ();
 		}
 	    }
