@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -135,11 +135,12 @@ lw6net_tcp_accept (char **incoming_ip,
 		  (*incoming_port) = (int) ntohs (name.sin_port);
 		}
 
-	      if (incoming_ip && incoming_port)
+	      if (incoming_ip && incoming_port && *incoming_ip
+		  && (*incoming_port) >= 0)
 		{
 		  lw6sys_log (LW6SYS_LOG_INFO,
 			      _("socket %d accepted from %s:%d"), new_sock,
-			      incoming_ip, incoming_port);
+			      *incoming_ip, *incoming_port);
 		}
 	    }
 	  else
