@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -71,13 +71,11 @@ extern int lw6net_tcp_recv (int sock, char *buf,
 			    int len, float delay, int loop);
 extern int lw6net_tcp_is_alive (int sock);
 
-/*
- * In test.c
- */
-extern int lw6net_test ();
+/* net-test.c */
+extern int lw6net_test (int mode);
 
 /*
- * In ucp.c
+ * In udp.c
  */
 extern int lw6net_udp_client ();
 extern int lw6net_udp_server (char *ip, int port);
