@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,9 +29,29 @@
 #include "../cli/cli.h"
 #include "../srv/srv.h"
 
-/*
- * In test.c
- */
-extern int lw6p2p_test ();
+typedef struct lw6p2p_node_s
+{
+  /*
+   * The first member, id, is the same as the internal
+   * _lw6p2p_node_t structure. The rest of it is hidden.
+   * The program will cast from lw6p2p_node_t to _lw6p2p_node_t
+   * internally.
+   */
+  u_int32_t id;
+} lw6p2p_node_t;
+
+/* p2p-node.c */
+extern lw6p2p_node_t *lw6p2p_node_new (int argc, char *argv[],
+				       char *client_backends,
+				       char *server_backends, char *bind_ip,
+				       int bind_port, u_int64_t server_id,
+				       char *public_url);
+extern void lw6p2p_node_free (lw6p2p_node_t * node);
+extern char *lw6p2p_node_repr (lw6p2p_node_t * node);
+extern int lw6p2p_node_poll (lw6p2p_node_t * node);
+extern void lw6p2p_node_close (lw6p2p_node_t * node);
+
+/* p2p-test.c */
+extern int lw6p2p_test (int mode);
 
 #endif
