@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -482,3 +482,53 @@ lw6pil_command_execute_text (lw6ker_game_state_t * game_state,
 
   return ret;
 }
+
+int
+lw6pil_command_execute_local (lw6pil_local_cursors_t * local_cursors,
+			      lw6pil_command_t * command)
+{
+  int ret = 0;
+
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("execute command \"%s\""), command->text);
+  switch (command->code)
+    {
+    case LW6PIL_COMMAND_CODE_NOP:
+    case LW6PIL_COMMAND_CODE_REGISTER:
+    case LW6PIL_COMMAND_CODE_ADD:
+    case LW6PIL_COMMAND_CODE_REMOVE:
+    case LW6PIL_COMMAND_CODE_UNREGISTER:
+      // do nothing!
+      ret = 1;
+      break;
+    case LW6PIL_COMMAND_CODE_SET:
+      ret =
+	lw6pil_local_cursors_set_xy (local_cursors,
+				     command->args.set.cursor_id,
+				     command->args.set.x,
+				     command->args.set.y);
+      break;
+    default:
+      lw6sys_log (LW6SYS_LOG_WARNING, _("incorrect command \"%s\""),
+		  command->text);
+      break;
+    }
+
+  return ret;
+}
+
+int
+lw6pil_command_execute_local_text (lw6pil_local_cursors_t * local_cursors,
+				   char *command_text)
+{
+  int ret = 0;
+  lw6pil_command_t *command = NULL;
+
+  command = lw6pil_command_new (command_text);
+  if (command)
+    {
+      ret = lw6pil_command_execute_local (local_cursors, command);
+      lw6pil_command_free (command);
+    }
+
+  return ret;
+}
