@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -240,6 +240,35 @@ lw6pil_pilot_send_command (lw6pil_pilot_t * pilot, char *command_text,
   return ret;
 }
 
+/**
+ * lw6pil_pilot_local_command
+ *
+ * @pilot: the object to apply the local command on
+ * @command_text: the command text
+ *
+ * This function is used to fix the annoying fact that by only sending
+ * commands a limited number of times per sec to the game state, the
+ * display always reflect an outdated position for cursors. But players
+ * do not want to see this, they want to see the cursor in the right place.
+ * So what we do is that the pilot can process "local" commands which have
+ * absolutely no effect on the game but simply update a local cursor state,
+ * only used for display. It's here in the pil module for it's where the
+ * command interpreting code is, and the fact that there's this lag is
+ * directly linked with the pilot way of doing things.
+ *
+ * Return value: 1 on success, 0 on failure.
+ */
+int
+lw6pil_pilot_local_command (lw6pil_pilot_t * pilot, char *command_text)
+{
+  int ret = 0;
+
+  ret =
+    lw6pil_command_execute_local_text (&(pilot->local_cursors), command_text);
+
+  return ret;
+}
+
 static void
 sync_draft_from_reference (lw6pil_pilot_t * pilot)
 {
