@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,11 +30,12 @@
 #define TEST_MAP_WIDTH 45
 #define TEST_MAP_HEIGHT 15
 #define TEST_MAP_NB_LAYERS 7
+#define TEST_MAP_NOISE_PERCENT 5
 #define TEST_CYCLE 0.5f
 #define TEST_NB_PILOTS 3
 #define TEST_SYNC_COMMAND_I 10
 #define TEST_BACKUP_ROUND 70
-#define TEST_BACKUP_CHECKSUM 0xcdbb7f42
+#define TEST_BACKUP_CHECKSUM 0xc4bb6842
 #define TEST_CALIBRATE_TICKS1 12345
 #define TEST_CALIBRATE_TICKS2 23456
 #define TEST_COORDS_NB 5
@@ -52,6 +53,14 @@
 #define TEST_COORDS_X5 1000.1f
 #define TEST_COORDS_Y5 51.1f
 #define TEST_COORDS_Z 0.0f
+#define _TEST_LOCAL_CURSORS_ID1 0x1234
+#define _TEST_LOCAL_CURSORS_X1 15
+#define _TEST_LOCAL_CURSORS_Y1 30
+#define _TEST_LOCAL_CURSORS_MOUSE_CONTROLLED1 1
+#define _TEST_LOCAL_CURSORS_ID2 0x2345
+#define _TEST_LOCAL_CURSORS_X2 45
+#define _TEST_LOCAL_CURSORS_Y2 90
+#define _TEST_LOCAL_CURSORS_MOUSE_CONTROLLED2 0
 
 static char *test_commands[] = {
   "2 1234abcd1234abcd REGISTER",
@@ -88,7 +97,7 @@ test_bench ()
   {
     float bench_result = 0.0f;
 
-    if (lw6pil_bench (&bench_result))
+    if (lw6pil_bench (&bench_result, NULL))
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE, _("bench=%0.1f"), bench_result);
 	ret = 1;
@@ -245,6 +254,77 @@ print_game_state (lw6ker_game_state_t * game_state, char *text)
     }
 }
 
+/*
+ * Testing local_cursors
+ */
+static int
+test_local_cursors ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6pil_local_cursors_t local_cursors;
+    u_int16_t cursor_id = 0;
+    int x = 0;
+    int y = 0;
+    int mouse_controlled = 0;
+
+    ret = 0;
+    lw6pil_local_cursors_reset (&local_cursors);
+    if (lw6pil_local_cursors_set_xy
+	(&local_cursors, _TEST_LOCAL_CURSORS_ID1, _TEST_LOCAL_CURSORS_X1,
+	 _TEST_LOCAL_CURSORS_Y1))
+      {
+	if (lw6pil_local_cursors_set_xy
+	    (&local_cursors, _TEST_LOCAL_CURSORS_ID2, _TEST_LOCAL_CURSORS_X2,
+	     _TEST_LOCAL_CURSORS_Y2))
+	  {
+	    if (lw6pil_local_cursors_set_mouse_controlled
+		(&local_cursors, _TEST_LOCAL_CURSORS_ID1,
+		 _TEST_LOCAL_CURSORS_MOUSE_CONTROLLED1))
+	      {
+		if (lw6pil_local_cursors_set_mouse_controlled
+		    (&local_cursors, _TEST_LOCAL_CURSORS_ID2,
+		     _TEST_LOCAL_CURSORS_MOUSE_CONTROLLED2))
+		  {
+		    if (lw6pil_local_cursors_get_info
+			(&local_cursors, &x, &y, &mouse_controlled,
+			 _TEST_LOCAL_CURSORS_ID1))
+		      lw6sys_log (LW6SYS_LOG_NOTICE,
+				  _
+				  ("cursor %x is at %d,%d mouse_controlled=%d"),
+				  _TEST_LOCAL_CURSORS_ID1, x, y,
+				  mouse_controlled);
+		    if (lw6pil_local_cursors_set_main
+			(&local_cursors, _TEST_LOCAL_CURSORS_ID2))
+		      {
+			if (lw6pil_local_cursors_get_main_info
+			    (&local_cursors, &cursor_id, &x, &y,
+			     &mouse_controlled))
+			  {
+			    lw6sys_log (LW6SYS_LOG_NOTICE,
+					_
+					("main cursor %x is at %d,%d mouse_controlled=%d"),
+					cursor_id, x, y, mouse_controlled);
+			    if (lw6pil_local_cursors_get_cursor
+				(&local_cursors, cursor_id))
+			      {
+				ret = 1;
+			      }
+			  }
+		      }
+		  }
+	      }
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+
+  return ret;
+}
+
 /*
  * Testing functions in pilot.c
  */
@@ -264,8 +344,8 @@ test_pilot ()
     u_int32_t checksum = 0;
 
     level =
-      lw6map_builtin_whd (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
-			  TEST_MAP_NB_LAYERS);
+      lw6map_builtin_custom (TEST_MAP_WIDTH, TEST_MAP_HEIGHT,
+			     TEST_MAP_NB_LAYERS, TEST_MAP_NOISE_PERCENT);
     if (level)
       {
 	/*
@@ -312,6 +392,9 @@ test_pilot ()
 									     +
 									     2],
 							       0);
+				    lw6pil_pilot_local_command (pilot,
+								test_commands
+								[i + 2]);
 				  }
 			      }
 			    lw6pil_pilot_commit (pilot);
@@ -449,12 +532,14 @@ test_pilot ()
 /**
  * lw6pil_test
  *
+ * @mode: 0 for check only, 1 for full test
+ *
  * Runs the @pil module test suite.
  *
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6pil_test ()
+lw6pil_test (int mode)
 {
   int ret = 0;
 
@@ -463,12 +548,13 @@ lw6pil_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6map_test ();
-      lw6ker_test ();
+      lw6sys_test (mode);
+      lw6map_test (mode);
+      lw6ker_test (mode);
     }
 
-  ret = test_command () && test_coords () && test_pilot () && test_bench ();
+  ret = test_command () && test_coords () && test_local_cursors ()
+    && test_pilot () && test_bench ();
 
   return ret;
 }
