@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,8 +54,15 @@ extern int _mod_csound_play_sound (_mod_csound_context_t * csound_context,
 /*
  * In music.c
  */
-extern int _mod_csound_play_music (_mod_csound_context_t * csound_context,
-				   char *music_name);
+extern int _mod_csound_is_music_file (_mod_csound_context_t *
+				      csound_context, char *music_file);
+extern int _mod_csound_play_music_file (_mod_csound_context_t *
+					csound_context, char *music_file);
+extern int _mod_csound_play_music_random (_mod_csound_context_t *
+					  csound_context, char *music_path,
+					  char *music_filter,
+					  char *music_exclude);
+extern void _mod_csound_stop_music (_mod_csound_context_t * csound_context);
 
 /*
  * In path.c
