@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,9 +27,9 @@
 #include "../snd.h"
 #include "mod-csound-internal.h"
 
-extern int
-_mod_csound_play_music (_mod_csound_context_t * csound_context,
-			char *music_name)
+int
+_mod_csound_is_music_file (_mod_csound_context_t *
+			   csound_context, char *music_file)
 {
   int ret = 0;
 
@@ -38,3 +38,34 @@ _mod_csound_play_music (_mod_csound_context_t * csound_context,
 
   return ret;
 }
+
+int
+_mod_csound_play_music_file (_mod_csound_context_t * snd_context,
+			     char *music_file)
+{
+  int ret = 0;
+
+  // todo...
+  ret = 1;
+
+  return ret;
+}
+
+int
+_mod_csound_play_music_random (_mod_csound_context_t * csound_context,
+			       char *music_path, char *music_filter,
+			       char *music_exclude)
+{
+  int ret = 0;
+
+  // todo...
+  ret = 1;
+
+  return ret;
+}
+
+void
+_mod_csound_stop_music (_mod_csound_context_t * csound_context)
+{
+  // todo...
+}
