@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -56,12 +56,21 @@ typedef struct _mod_ogg_sounds_s
 }
 _mod_ogg_sounds_t;
 
+typedef struct _mod_ogg_music_s
+{
+  Mix_Music *music;
+  char *filter;
+  char *exclude;
+}
+_mod_ogg_music_t;
+
 typedef struct _mod_ogg_context_s
 {
   _mod_ogg_path_t path;
   _mod_ogg_volume_t volume;
   _mod_ogg_const_data_t const_data;
   _mod_ogg_sounds_t sounds;
+  _mod_ogg_music_t music;
 }
 _mod_ogg_context_t;
 
@@ -82,8 +91,14 @@ extern void _mod_ogg_unload_sounds (_mod_ogg_context_t * ogg_context);
 /*
  * In music.c
  */
-extern int _mod_ogg_play_music (_mod_ogg_context_t * ogg_context,
-				char *music_name);
+extern int _mod_ogg_is_music_file (_mod_ogg_context_t *
+				   ogg_context, char *music_file);
+extern int _mod_ogg_play_music_file (_mod_ogg_context_t * ogg_context,
+				     char *music_file);
+extern int _mod_ogg_play_music_random (_mod_ogg_context_t * ogg_context,
+				       char *music_path, char *music_filter,
+				       char *music_exclude);
+extern void _mod_ogg_stop_music (_mod_ogg_context_t * ogg_context);
 
 /*
  * In path.c
