@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,9 @@
 #define TEST_SOUND_VOLUME 0.6f
 #define TEST_MUSIC_VOLUME 0.4f
 #define TEST_SOUND_SLEEP 1.0f
+#define TEST_MUSIC_SLEEP 10.0f
+#define TEST_MUSIC_FILTER ""
+#define TEST_MUSIC_EXCLUDE ""
 #define TEST_ARGC 1
 #define TEST_ARGV0 "prog"
 
@@ -83,6 +86,47 @@ test_play_sound (lw6snd_backend_t * backend)
   return ret;
 }
 
+static int
+test_play_music (lw6snd_backend_t * backend)
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *map_path = NULL;
+    int argc = TEST_ARGC;
+    char *argv[TEST_ARGC] = { TEST_ARGV0 };
+
+    map_path = lw6cfg_unified_get_music_path (argc, argv);
+    if (map_path)
+      {
+	if (lw6snd_play_music_random
+	    (backend, map_path, TEST_MUSIC_FILTER, TEST_MUSIC_EXCLUDE))
+	  {
+	    lw6sys_sleep (TEST_MUSIC_SLEEP);
+	    if (lw6snd_play_music_random
+		(backend, map_path, TEST_MUSIC_FILTER, TEST_MUSIC_EXCLUDE))
+	      {
+		lw6sys_sleep (TEST_MUSIC_SLEEP);
+	      }
+	    else
+	      {
+		ret = 0;
+	      }
+	    lw6snd_stop_music (backend);
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+	LW6SYS_FREE (map_path);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 test_quit (lw6snd_backend_t * backend)
 {
@@ -95,8 +139,19 @@ test_quit (lw6snd_backend_t * backend)
   return ret;
 }
 
+/**
+ * lw6snd_test
+ *
+ * @mode: 0 for check only, 1 for full test
+ *
+ * Runs the @snd module test suite. If run in check mode (0),
+ * won't really perform the test, since it could fail because
+ * of hardware problems, context, permissions...
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
-lw6snd_test ()
+lw6snd_test (int mode)
 {
   int ret = 1;
   lw6snd_backend_t *backend;
@@ -108,29 +163,36 @@ lw6snd_test ()
       /*
        * Just to make sure most functions are stuffed in the binary
        */
-      lw6sys_test ();
-      lw6cfg_test ();
+      lw6sys_test (mode);
+      lw6cfg_test (mode);
     }
 
-#ifdef MOD_OGG
-  backend = lw6snd_create_backend (argc, argv, "ogg");
-  if (backend)
+  if (mode)
     {
-      ret = test_init (backend) && test_play_sound (backend)
-	&& test_quit (backend) && ret;
-      lw6snd_destroy_backend (backend);
-    }
+#ifdef MOD_OGG
+      backend = lw6snd_create_backend (argc, argv, "ogg");
+      if (backend)
+	{
+	  ret = test_init (backend) && test_play_sound (backend)
+	    && test_play_music (backend) && test_quit (backend) && ret;
+	  lw6snd_destroy_backend (backend);
+	}
 #endif
 
 #ifdef MOD_CSOUND
-  backend = lw6snd_create_backend (argc, argv, "csound");
-  if (backend)
-    {
-      ret = test_init (backend) && test_play_sound (backend)
-	&& test_quit (backend) && ret;
-      lw6snd_destroy_backend (backend);
-    }
+      backend = lw6snd_create_backend (argc, argv, "csound");
+      if (backend)
+	{
+	  ret = test_init (backend) && test_play_sound (backend)
+	    && test_quit (backend) && ret;
+	  lw6snd_destroy_backend (backend);
+	}
 #endif
+    }
+  else
+    {
+      ret = 1;
+    }
 
   return ret;
 }
