@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,7 +47,11 @@ typedef struct lw6snd_backend_s
   u_int32_t id;
 
   int (*play_sound) (void *snd_context, int sound_id);
-  int (*play_music) (void *snd_context, char *music_name);
+  int (*is_music_file) (void *snd_context, char *music_file);
+  int (*play_music_file) (void *snd_context, char *music_file);
+  int (*play_music_random) (void *snd_context, char *music_path,
+			    char *music_filter, char *music_exclude);
+  void (*stop_music) (void *snd_context);
   void *(*init) (int argc, char *argv[], float sound_volume,
 		 float music_volume);
   void (*set_sound_volume) (void *snd_context, float volume);
@@ -61,7 +65,16 @@ lw6snd_backend_t;
  * In api.c
  */
 extern int lw6snd_play_sound (lw6snd_backend_t * backend, int sound_id);
-extern int lw6snd_play_music (lw6snd_backend_t * backend, char *music_name);
+extern int lw6snd_is_music_file (lw6snd_backend_t * backend,
+				 char *map_dir,
+				 char *music_path, char *music_file);
+extern int lw6snd_play_music_file (lw6snd_backend_t * backend,
+				   char *map_dir,
+				   char *music_path, char *music_file);
+extern int lw6snd_play_music_random (lw6snd_backend_t * backend,
+				     char *music_path, char *music_filter,
+				     char *music_exclude);
+extern void lw6snd_stop_music (lw6snd_backend_t * backend);
 extern char *lw6snd_repr (lw6snd_backend_t * snd_backend);
 extern int lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
 			float music_volume);
@@ -80,9 +93,7 @@ extern lw6snd_backend_t *lw6snd_create_backend (int argc, char *argv[],
 						char *name);
 extern void lw6snd_destroy_backend (lw6snd_backend_t * backend);
 
-/*
- * In test.c
- */
-extern int lw6snd_test ();
+/* snd-test.c */
+extern int lw6snd_test (int mode);
 
 #endif
