@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,6 +33,14 @@
 #include "mod-httpd/mod-httpd.h"
 #endif
 
+#define _SRV_DEFAULT_BACKENDS "tcpd,udpd,httpd"
+
+char *
+lw6srv_default_backends ()
+{
+  return _SRV_DEFAULT_BACKENDS;
+}
+
 lw6sys_assoc_t *
 lw6srv_get_backends (int argc, char *argv[])
 {
