@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,9 @@
 #include "sys.h"
 #include "sys-build.h"
 
-#define COPYRIGHT "Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>"
+#define COPYRIGHT "Copyright (C)  2010  Christian Mauduit <ufoot@ufoot.org>"
 #define LICENSE "GPLv3+ (GNU GPL version 3 or later)"
+#define URL "http://www.gnu.org/software/liquidwar6/"
 #define TOP_SRCDIR_TEST_FILE "liquidwar6.spec.in"
 #define TOP_SRCDIR_MAX_UNPARENT 4
 #define ENABLE_YES "yes"
@@ -199,6 +200,20 @@ lw6sys_build_get_license ()
   return LICENSE;
 }
 
+/**
+ * lw6sys_build_get_url:
+ *
+ * Returns the URL of the game, its homepage.
+ *
+ * Return value: a non-NULL string, single line whithout '\n' at the end. 
+ *   Must not be freed.
+ */
+char *
+lw6sys_build_get_url ()
+{
+  return URL;
+}
+
 /**
  * lw6sys_build_get_configure_args:
  *
@@ -316,7 +331,7 @@ lw6sys_build_get_time ()
 }
 
 /**
- * lw6sys_build_get_target_cpu:
+ * lw6sys_build_get_host_cpu:
  *
  * Returns the CPU this program is designed for. Convenient on i386 compatible
  * CPUs to know which flavor (i386, i586...) the binary is made for.
@@ -324,9 +339,9 @@ lw6sys_build_get_time ()
  * Return value: a non-NULL string, must not be freed.
  */
 char *
-lw6sys_build_get_target_cpu ()
+lw6sys_build_get_host_cpu ()
 {
-  return LW6_TARGET_CPU;
+  return LW6_HOST_CPU;
 }
 
 /**
@@ -381,16 +396,16 @@ lw6sys_build_is_x86 ()
 }
 
 /**
- * lw6sys_build_get_target_os:
+ * lw6sys_build_get_host_os:
  *
  * Returns the OS this program is designed for. Usefull for bug reports.
  *
  * Return value: a non-NULL string, must not be freed.
  */
 char *
-lw6sys_build_get_target_os ()
+lw6sys_build_get_host_os ()
 {
-  return LW6_TARGET_OS;
+  return LW6_HOST_OS;
 }
 
 /**
@@ -427,6 +442,23 @@ lw6sys_build_is_mac_os_x ()
 #endif
 }
 
+/**
+ * lw6sys_build_is_gp2x:
+ *
+ * Tells wether the program was compiled for GP2X, or not.
+ *
+ * Return value: 1 if compiled on OS X, 0 if not
+ */
+int
+lw6sys_build_is_gp2x ()
+{
+#ifdef LW6_GP2X
+  return 1;
+#else
+  return 0;
+#endif
+}
+
 /**
  * lw6sys_build_get_top_srcdir:
  *
@@ -814,10 +846,125 @@ lw6sys_build_get_enable_valgrind ()
 #endif
 }
 
+/**
+ * lw6sys_build_get_bin_id
+ *
+ * Returns the internal bin-id value, which does not mean anything
+ * but changes at each build.
+ *
+ * Return value: an integer
+ */
+int
+lw6sys_build_get_bin_id ()
+{
+  int ret = 0;
+  u_int32_t checksum_global = 0;
+  u_int32_t checksum_version = 0;
+  u_int32_t ret_global = 0;
+  u_int32_t ret_version = 0;
+
+  /*
+   * OK, yes, this is a little overkill for what there's to do.
+   * But at least we're sure we didn't forget anything. If one
+   * recompiles the game, for sure, bin-id changes.
+   */
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_package_tarname ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_package_name ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_package_string ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_version ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_codename ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_stamp ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_md5sum ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_copyright ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_license ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_url ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_configure_args ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_gcc_version ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_cflags ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_ldflags ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_hostname ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_date ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_time ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_host_cpu ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_endianness ());
+  lw6sys_checksum_update_int32 (&checksum_global,
+				lw6sys_build_get_pointer_size ());
+  lw6sys_checksum_update_int32 (&checksum_global, lw6sys_build_is_x86 ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_host_os ());
+  lw6sys_checksum_update_int32 (&checksum_global,
+				lw6sys_build_is_ms_windows ());
+  lw6sys_checksum_update_int32 (&checksum_global,
+				lw6sys_build_is_mac_os_x ());
+  lw6sys_checksum_update_int32 (&checksum_global, lw6sys_build_is_gp2x ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_top_srcdir ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_prefix ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_datadir ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_libdir ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_includedir ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_localedir ());
+  lw6sys_checksum_update_str (&checksum_global, lw6sys_build_get_docdir ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_console ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_mod_gl ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_mod_csound ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_mod_ogg ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_mod_http ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_optimize ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_allinone ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_fullstatic ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_paranoid ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_gprof ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_instrument ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_profiler ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_gcov ());
+  lw6sys_checksum_update_str (&checksum_global,
+			      lw6sys_build_get_enable_valgrind ());
+
+  checksum_version = lw6sys_checksum_str (lw6sys_build_get_version ());
+
+  /*
+   * It can seem strange to include version *again* in another checksum
+   * and "prefix" it. Why not use checksum_global only after all?
+   * The reason is that most of the time, we want to track a version change.
+   * We certainly don't want a collision between two binaries with different
+   * versions. It's also easy to check the bin-id starts with the same
+   * numbers for a given version. Yes, it's overkill to do all the above
+   * for a few digits, but it's not that bad, in case of doubt there's always
+   * '--pedigree'.
+   */
+  ret_version = 10000 * (10000 + checksum_version % 90000);
+  ret_global = checksum_global % 10000;
+  ret = ret_version + ret_global;
+
+  return ret;
+}
+
 /**
  * lw6sys_build_log_all
  *
- * Dumps in the log file the whole program pedigree, target, modules,
+ * Dumps in the log file the whole program pedigree, host, modules,
  * that is, what are the values of all the build options. 
  * Usefull for bug reports.
  *
@@ -844,6 +991,8 @@ lw6sys_build_log_all ()
 	      lw6sys_build_get_copyright ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build license is \"%s\""),
 	      lw6sys_build_get_license ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build url is \"%s\""),
+	      lw6sys_build_get_url ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build configure args is \"%s\""),
 	      lw6sys_build_get_configure_args ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build gcc_version is \"%s\""),
@@ -856,16 +1005,20 @@ lw6sys_build_log_all ()
 	      lw6sys_build_get_date ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build time is \"%s\""),
 	      lw6sys_build_get_time ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build target cpu is \"%s\""),
-	      lw6sys_build_get_target_cpu ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build host cpu is \"%s\""),
+	      lw6sys_build_get_host_cpu ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build endianness is \"%s\""),
 	      lw6sys_build_get_endianness ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build pointer size is %d"),
 	      lw6sys_build_get_pointer_size ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build target os is \"%s\""),
-	      lw6sys_build_get_target_os ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build host os is \"%s\""),
+	      lw6sys_build_get_host_os ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build ms windows is %d"),
 	      lw6sys_build_is_ms_windows ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build mac os x is %d"),
+	      lw6sys_build_is_mac_os_x ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build gp2x is %d"),
+	      lw6sys_build_is_gp2x ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build top_srcdir is \"%s\""),
 	      lw6sys_build_get_top_srcdir ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build prefix is \"%s\""),
@@ -908,4 +1061,6 @@ lw6sys_build_log_all ()
 	      lw6sys_build_get_enable_gcov ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable valgrind is \"%s\""),
 	      lw6sys_build_get_enable_valgrind ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build bin-id is %d"),
+	      lw6sys_build_get_bin_id ());
 }
