@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,7 +52,6 @@
 // ticks limit set to 15 minutes
 #define _LW6SYS_TICKS_LIMIT 900000
 
-#define _LW6SYS_THREAD_JOIN_SLEEP 0.1f
 #define _LW6SYS_VTHREAD_ID -1
 
 typedef struct _lw6sys_bazooka_s
@@ -91,7 +90,6 @@ typedef struct _lw6sys_thread_handler_s
   pthread_t thread;
   u_int32_t id;
   int callback_done;
-  int join_done;
   int can_join;
   void (*callback_func) (void *callback_data);
   void (*callback_join) (void *callback_data);
@@ -101,6 +99,12 @@ typedef struct _lw6sys_thread_handler_s
 #endif
 } _lw6sys_thread_handler_t;
 
+typedef struct _lw6sys_vthread_handler_s
+{
+  int join_done;
+  _lw6sys_thread_handler_t thread;
+} _lw6sys_vthread_handler_t;
+
 typedef struct _lw6sys_global_s
 {
   int debug;
