@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ lw6sys_malloc (int size, char *file, int line)
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("out of memory malloc (%d) failed in %s:%d)"), size, file,
+		  _("out of memory malloc (%d) failed in %s:%d"), size, file,
 		  line);
     }
 
@@ -115,7 +115,7 @@ lw6sys_calloc (int size, char *file, int line)
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("out of memory calloc(%d) failed in %s:%d)"), size, file,
+		  _("out of memory calloc(%d) failed in %s:%d"), size, file,
 		  line);
     }
 
@@ -171,7 +171,7 @@ lw6sys_realloc (void *ptr, int size, char *file, int line)
   else
     {
       lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("out of memory realloc (%d) failed in %s:%d)"), size,
+		  _("out of memory realloc (%d) failed in %s:%d"), size,
 		  file, line);
     }
 
