@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -38,11 +38,17 @@
 #define MOD_PREFIX_MASK "%s/lib/%s-%s"
 #define SHARE_DATADIR_MASK "%s/%s-%s"
 #define SHARE_PREFIX_MASK "%s/share/%s-%s"
+#ifdef LW6_MAC_OS_X
+#define RUN_REL "../Resources"
+#else
+#define RUN_REL ".."
+#endif
 #define DATA_DIR "data"
+#define MUSIC_DIR "music"
 #define MAP_DIR "map"
 #define SCRIPT_FILE "script/liquidwar6.scm"
 #ifdef LW6_MS_WINDOWS
-#define README_FILE "README.txt"
+#define README_FILE "readme.txt"
 #else
 #define README_FILE "README"
 #endif
@@ -262,6 +268,7 @@ get_dir_argc_argv (int argc, char *argv[], char *mask1, char *prefix1,
 {
   char *dir = NULL;
   char *run_dir = NULL;
+  char *run_dir_rel;
 
   dir = get_dir_common (mask1, prefix1, mask2, prefix2, sub);
 
@@ -278,6 +285,28 @@ get_dir_argc_argv (int argc, char *argv[], char *mask1, char *prefix1,
 		  // directory doesn't exist, we ignore it
 		  LW6SYS_FREE (dir);
 		  dir = NULL;
+
+		  if (RUN_REL && strlen (RUN_REL))
+		    {
+		      run_dir_rel = lw6sys_path_concat (run_dir, RUN_REL);
+		      if (run_dir_rel)
+			{
+			  if (lw6sys_dir_exists (run_dir_rel))
+			    {
+			      dir = lw6sys_path_concat (run_dir_rel, sub);
+			      if (dir)
+				{
+				  if (!lw6sys_dir_exists (dir))
+				    {
+				      LW6SYS_FREE (dir);
+				      dir = NULL;
+				      // directory doesn't exist, we ignore it
+				    }
+				}
+			    }
+			  LW6SYS_FREE (run_dir_rel);
+			}
+		    }
 		}
 	    }
 	  LW6SYS_FREE (run_dir);
@@ -385,6 +414,7 @@ get_file_argc_argv (int argc, char *argv[], char *mask1, char *prefix1,
 {
   char *file = NULL;
   char *run_dir = NULL;
+  char *run_dir_rel = NULL;
 
   file = get_file_common (mask1, prefix1, mask2, prefix2, sub);
 
@@ -398,9 +428,31 @@ get_file_argc_argv (int argc, char *argv[], char *mask1, char *prefix1,
 	    {
 	      if (!lw6sys_file_exists (file))
 		{
-		  // file doesn't exist, we ignore it
 		  LW6SYS_FREE (file);
 		  file = NULL;
+		  // file doesn't exist, we ignore it
+
+		  if (RUN_REL && strlen (RUN_REL))
+		    {
+		      run_dir_rel = lw6sys_path_concat (run_dir, RUN_REL);
+		      if (run_dir_rel)
+			{
+			  if (lw6sys_dir_exists (run_dir_rel))
+			    {
+			      file = lw6sys_path_concat (run_dir_rel, sub);
+			      if (file)
+				{
+				  if (!lw6sys_file_exists (file))
+				    {
+				      LW6SYS_FREE (file);
+				      file = NULL;
+				      // file doesn't exist, we ignore it
+				    }
+				}
+			    }
+			  LW6SYS_FREE (run_dir_rel);
+			}
+		    }
 		}
 	    }
 	  LW6SYS_FREE (run_dir);
@@ -516,29 +568,6 @@ lw6sys_get_default_data_dir ()
   return data_dir;
 }
 
-/**
- * lw6sys_get_default_map_dir
- *
- * Returns the default map directory.
- *
- * Return value: a newly allocated string.
- */
-char *
-lw6sys_get_default_map_dir ()
-{
-  char *map_dir = NULL;
-  char *prefix = NULL;
-
-  prefix = lw6sys_get_default_prefix ();
-  if (prefix)
-    {
-      map_dir = get_share_dir_with_prefix (prefix, MAP_DIR);
-      LW6SYS_FREE (prefix);
-    }
-
-  return map_dir;
-}
-
 static char *
 get_path_with_dir_and_user_dir (char *dir, char *user_dir, char *sub,
 				int create_dir, char *readme_comment)
@@ -584,6 +613,83 @@ get_path_with_dir_and_user_dir (char *dir, char *user_dir, char *sub,
   return path;
 }
 
+/**
+ * lw6sys_get_default_music_dir
+ *
+ * Returns the default music directory.
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_default_music_dir ()
+{
+  char *music_dir = NULL;
+  char *prefix = NULL;
+
+  prefix = lw6sys_get_default_prefix ();
+  if (prefix)
+    {
+      music_dir = get_share_dir_with_prefix (prefix, MUSIC_DIR);
+      LW6SYS_FREE (prefix);
+    }
+
+  return music_dir;
+}
+
+/**
+ * lw6sys_get_default_music_path
+ *
+ * Returns the default music path, which can be composed of several directories.
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_default_music_path ()
+{
+  char *music_path = NULL;
+  char *music_dir = NULL;
+  char *user_dir = NULL;
+
+  music_dir = lw6sys_get_default_music_dir ();
+  if (music_dir)
+    {
+      user_dir = lw6sys_get_default_user_dir ();
+      if (user_dir)
+	{
+	  music_path =
+	    get_path_with_dir_and_user_dir (music_dir, user_dir, MUSIC_DIR, 0,
+					    NULL);
+	  LW6SYS_FREE (user_dir);
+	}
+      LW6SYS_FREE (music_dir);
+    }
+
+  return music_path;
+}
+
+/**
+ * lw6sys_get_default_map_dir
+ *
+ * Returns the default map directory.
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_default_map_dir ()
+{
+  char *map_dir = NULL;
+  char *prefix = NULL;
+
+  prefix = lw6sys_get_default_prefix ();
+  if (prefix)
+    {
+      map_dir = get_share_dir_with_prefix (prefix, MAP_DIR);
+      LW6SYS_FREE (prefix);
+    }
+
+  return map_dir;
+}
+
 /**
  * lw6sys_get_default_map_path
  *
@@ -713,6 +819,18 @@ lw6sys_options_log_defaults ()
       lw6sys_log (LW6SYS_LOG_INFO, _("default data dir is \"%s\""), path);
       LW6SYS_FREE (path);
     }
+  path = lw6sys_get_default_music_dir ();
+  if (path)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("default music dir is \"%s\""), path);
+      LW6SYS_FREE (path);
+    }
+  path = lw6sys_get_default_music_path ();
+  if (path)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("default music path is \"%s\""), path);
+      LW6SYS_FREE (path);
+    }
   path = lw6sys_get_default_map_dir ();
   if (path)
     {
@@ -1014,6 +1132,100 @@ lw6sys_get_data_dir (int argc, char *argv[])
   return data_dir;
 }
 
+/**
+ * lw6sys_get_music_dir
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the music dir, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result.
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_music_dir (int argc, char *argv[])
+{
+  char *music_dir = NULL;
+  char *prefix = NULL;
+
+  music_dir = get_command_arg_with_env (argc, argv, LW6DEF_MUSIC_DIR);
+  if (music_dir == NULL)
+    {
+      prefix = lw6sys_get_prefix (argc, argv);
+      if (prefix)
+	{
+	  music_dir =
+	    get_share_dir_with_prefix_argc_argv (argc, argv, prefix,
+						 MUSIC_DIR);
+	  LW6SYS_FREE (prefix);
+	}
+    }
+
+  return music_dir;
+}
+
+/**
+ * lw6sys_get_music_path
+ *
+ * @argc: argc, number of arguments, as given to @main
+ * @argv: argv, pointer to arguments, as given to @main
+ *
+ * Returns the music path, taking in account command-line and
+ * environment variables. However config file content has no impact
+ * on the result. Music path can contain several directories.
+ *
+ * Return value: a newly allocated string.
+ */
+char *
+lw6sys_get_music_path (int argc, char *argv[])
+{
+  char *music_path = NULL;
+  char *music_path_cmd = NULL;
+  char *music_path_env = NULL;
+  char *music_dir = NULL;
+  char *user_dir = NULL;
+  char *tmp = NULL;
+
+  music_dir = lw6sys_get_music_dir (argc, argv);
+  if (music_dir)
+    {
+      user_dir = lw6sys_get_user_dir (argc, argv);
+      if (user_dir)
+	{
+	  music_path =
+	    get_path_with_dir_and_user_dir (music_dir, user_dir, MUSIC_DIR, 1,
+					    _
+					    ("This is your Liquid War 6 user music directory. You can put your own musics here, they will be automatically loaded by the game, and played."));
+	  if (music_path)
+	    {
+	      music_path_env = lw6sys_getenv (LW6DEF_MUSIC_PATH);
+	      if (music_path && music_path_env)
+		{
+		  tmp = music_path;
+		  music_path = lw6sys_env_concat (music_path_env, music_path);
+		  LW6SYS_FREE (tmp);
+		  LW6SYS_FREE (music_path_env);
+		}
+	      music_path_cmd =
+		lw6sys_arg_get_value (argc, argv, LW6DEF_MUSIC_PATH);
+	      if (music_path && music_path_cmd)
+		{
+		  tmp = music_path;
+		  music_path = lw6sys_env_concat (music_path_cmd, music_path);
+		  LW6SYS_FREE (tmp);
+		  LW6SYS_FREE (music_path_cmd);
+		}
+	    }
+	  LW6SYS_FREE (user_dir);
+	}
+      LW6SYS_FREE (music_dir);
+    }
+
+  return music_path;
+}
+
 /**
  * lw6sys_get_map_dir
  *
@@ -1205,6 +1417,18 @@ lw6sys_options_log (int argc, char *argv[])
       lw6sys_log (LW6SYS_LOG_INFO, _("data dir is \"%s\""), path);
       LW6SYS_FREE (path);
     }
+  path = lw6sys_get_music_dir (argc, argv);
+  if (path)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("music dir is \"%s\""), path);
+      LW6SYS_FREE (path);
+    }
+  path = lw6sys_get_music_path (argc, argv);
+  if (path)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("music path is \"%s\""), path);
+      LW6SYS_FREE (path);
+    }
   path = lw6sys_get_map_dir (argc, argv);
   if (path)
     {
