@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 #include "config.h"
 #endif
 
+#include <ctype.h>
+
 #include "sys.h"
 #include "sys-internal.h"
 
@@ -553,3 +555,65 @@ lw6sys_str_split_no_0 (char *str, char c)
 
   return ret;
 }
+
+/**
+ * lw6sys_str_split_config_item
+ *
+ * @str: a string
+ *
+ * Splits a string, ignoring empty '0-length' members, and using
+ * the comma ',' as a separator. This is typically usefull
+ * for config elements such as backend lists. Only paths need
+ * another separator (platform-dependant).
+ *
+ * Return value: a list containing 0-terminated strings.
+ */
+lw6sys_list_t *
+lw6sys_str_split_config_item (char *str)
+{
+  return lw6sys_str_split_no_0 (str, ',');
+}
+
+/**
+ * lw6sys_str_toupper
+ *
+ * @str: the string to modify
+ *
+ * Transforms a string to upper case, the pointer must point
+ * to modifiable data.
+ *
+ * Return value: none, @str pointed data modified in-place
+ */
+void
+lw6sys_str_toupper (char *str)
+{
+  char *pos = str;
+
+  while (pos[0])
+    {
+      pos[0] = toupper (pos[0]);
+      pos++;
+    }
+}
+
+/**
+ * lw6sys_str_tolower
+ *
+ * @str: the string to modify
+ *
+ * Transforms a string to lower case, the pointer must point
+ * to modifiable data.
+ *
+ * Return value: none, @str pointed data modified in-place
+ */
+void
+lw6sys_str_tolower (char *str)
+{
+  char *pos = str;
+
+  while (pos[0])
+    {
+      pos[0] = tolower (pos[0]);
+      pos++;
+    }
+}
