@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -57,6 +57,11 @@
 #endif
 #define TEST_PATH_CWD "./"
 #define TEST_PATH_SPLIT "/foo/\\bar\\"
+#define _TEST_DIR_LIST_FUNC_DATA "foo,bar"
+#define _TEST_PATH_LIST_OTHER "."
+#define _FIND_IN_DIR_AND_PATH_DIR "/foo"
+#define _FIND_IN_DIR_AND_PATH_PATH "/bar:/etc"
+#define _FIND_IN_DIR_AND_PATH_FILE "hosts"
 #define MALLOC_SIZE 1048576
 #define THREAD_N 5
 #define THREAD_SLEEP_MAIN 0.66f
@@ -112,8 +117,9 @@
 #define TEST_REFORMAT_STR2 "this is a very long string it should be cut in some places but wherever there is a very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very long word it won't be cut.\n\nIt should even handle newlines in some places but well, this is not absolutely necessary"
 #define TEST_REFORMAT_PREFIX "# "
 #define TEST_REFORMAT_COLUMNS 40
-#define TEST_SPLIT_STR "/foo/bar"
+#define TEST_SPLIT_STR "/foo/bar,/foo/bar"
 #define TEST_SPLIT_CHAR 'o'
+#define _TEST_STR_LOWER_UPPER "foObaR!"
 #define TEST_SERIALIZE 12345
 #define TEST_SORT_LENGTH 10
 #define TEST_SORT_INT {9,3,4,5,6,8,7,2,0,1};
@@ -132,6 +138,7 @@
 #define TEST_RANDOM_FLOAT_MIN 100.0f
 #define TEST_RANDOM_FLOAT_MAX 101.0f
 #define TEST_PROGRESS_N 7
+#define TEST_PROGRESS_HERE 0.3
 #define TEST_HISTORY_MSG1 "1 too old"
 #define TEST_HISTORY_MSG2 "2 too old 2"
 #define TEST_HISTORY_MSG3 "3 oldest"
@@ -1651,6 +1658,33 @@ path_split_func (void *func_data, void *data)
   lw6sys_log (LW6SYS_LOG_NOTICE, _("path part \"%s\""), str);
 }
 
+static int
+_dir_list_filter (void *func_data, char *file)
+{
+  int ret = 0;
+
+  if (lw6sys_checksum_str (file) % 2)
+    {
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("keep \"%s\" (func_data=\"%s\")"),
+		  file, func_data);
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("discard \"%s\""), file);
+    }
+
+  return ret;
+}
+
+static void
+_dir_list_print (void *func_data, void *data)
+{
+  char *file = (char *) data;
+
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("entry \"%s\""), file);
+}
+
 /*
  * Testing functions in path.c
  */
@@ -1662,6 +1696,8 @@ test_path ()
 
   {
     char *path = NULL;
+    char *path2 = NULL;
+    int n = 0;
     int relative = 0;
     int cwd = 0;
     lw6sys_list_t *list = NULL;
@@ -1736,6 +1772,51 @@ test_path ()
 	lw6sys_list_map (list, path_split_func, NULL);
 	lw6sys_list_free (list);
       }
+
+    path = lw6sys_get_home ();
+    if (path)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("listing dir \"%s\""), path);
+	list =
+	  lw6sys_dir_list (path, _dir_list_filter, _TEST_DIR_LIST_FUNC_DATA,
+			   &n);
+	if (list)
+	  {
+	    lw6sys_list_map (list, _dir_list_print, NULL);
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("%d items found in \"%s\""), n,
+			path);
+	    lw6sys_list_free (list);
+	  }
+	path2 = lw6sys_env_concat (path, _TEST_PATH_LIST_OTHER);
+	if (path2)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("listing path \"%s\""), path2);
+	    list =
+	      lw6sys_path_list (path2, _dir_list_filter,
+				_TEST_DIR_LIST_FUNC_DATA, &n);
+	    if (list)
+	      {
+		lw6sys_list_map (list, _dir_list_print, NULL);
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("%d items found in \"%s\""),
+			    n, path2);
+		lw6sys_list_free (list);
+	      }
+	    LW6SYS_FREE (path2);
+	  }
+	LW6SYS_FREE (path);
+      }
+    path =
+      lw6sys_find_in_dir_and_path (_FIND_IN_DIR_AND_PATH_DIR,
+				   _FIND_IN_DIR_AND_PATH_PATH,
+				   _FIND_IN_DIR_AND_PATH_FILE);
+    if (path)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("found \"%s\" with dir=\"%s\" path=\"%s\" file=\"%s\""),
+		    path, _FIND_IN_DIR_AND_PATH_DIR,
+		    _FIND_IN_DIR_AND_PATH_PATH, _FIND_IN_DIR_AND_PATH_FILE);
+	LW6SYS_FREE (path);
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -1772,6 +1853,11 @@ test_progress ()
     lw6sys_progress_half (&progress);
     lw6sys_progress_end (&progress);
     lw6sys_progress_split (&progress1, &progress2, &progress);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f"),
+		progress1.min, progress1.max, progress2.min, progress2.max);
+    lw6sys_progress_split_here (&progress1, &progress2, &progress,
+				TEST_PROGRESS_HERE);
     lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f"),
 		progress1.min, progress1.max, progress2.min, progress2.max);
@@ -2136,6 +2222,24 @@ test_str ()
 	lw6sys_list_map (list, str_split_func, NULL);
 	lw6sys_list_free (list);
       }
+
+    list = lw6sys_str_split_config_item (TEST_SPLIT_STR);
+    if (list)
+      {
+	lw6sys_list_map (list, str_split_func, NULL);
+	lw6sys_list_free (list);
+      }
+
+    str = lw6sys_str_copy (_TEST_STR_LOWER_UPPER);
+    if (str)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("original string=\"%s\""), str);
+	lw6sys_str_tolower (str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("lowered string=\"%s\""), str);
+	lw6sys_str_toupper (str);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("uppered string=\"%s\""), str);
+	LW6SYS_FREE (str);
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -2260,6 +2364,18 @@ test_shape ()
       {
 	ret = 0;
       }
+    if (lw6sys_shape_is_same_xy (&shape, &shape)
+	&& !lw6sys_shape_is_same_xy (&shape, &shape2))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("shape %dx%d reported different as %dx%d"),
+		    (int) shape.w, (int) shape.h,
+		    (int) shape2.w, (int) shape2.h);
+      }
+    else
+      {
+	ret = 0;
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -2417,24 +2533,26 @@ test_time ()
     int64_t last_uptime;
     int64_t uptime = 0;
     int64_t timestamp = 0;
+    int32_t cycle = 0;
 
     lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %" LW6SYS_PRINTF_LL "d"),
-		lw6sys_timestamp ());
+		lw6sys_get_timestamp ());
     lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %" LW6SYS_PRINTF_LL "d"),
-		lw6sys_uptime ());
+		lw6sys_get_uptime ());
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("cycle %d"), lw6sys_get_cycle ());
     lw6sys_idle ();
-    lw6sys_timer_update (&timestamp, &uptime);
+    lw6sys_timer_update (&timestamp, &uptime, &cycle);
     lw6sys_log (LW6SYS_LOG_NOTICE,
-		_("timestamp %" LW6SYS_PRINTF_LL "d uptime %" LW6SYS_PRINTF_LL
-		  "d"), timestamp, uptime);
-    last_uptime = lw6sys_uptime ();
+		_("timestamp=%" LW6SYS_PRINTF_LL "d uptime=%" LW6SYS_PRINTF_LL
+		  "d cycle=%d"), timestamp, uptime, cycle);
+    last_uptime = lw6sys_get_uptime ();
     lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds"), TEST_SLEEP_TIME);
     lw6sys_sleep (TEST_SLEEP_TIME);
     lw6sys_log (LW6SYS_LOG_NOTICE, _("delay %d msec"), TEST_DELAY_TIME);
     lw6sys_delay (TEST_DELAY_TIME);
     lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %" LW6SYS_PRINTF_LL "d ms"),
-		lw6sys_uptime () - last_uptime);
-    last_uptime = lw6sys_uptime ();
+		lw6sys_get_uptime () - last_uptime);
+    last_uptime = lw6sys_get_uptime ();
     nb_steps = TEST_SLEEP_TIME / TEST_SLEEP_TIME_SHORT_STEP;
     lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds using %d %0.6f steps"),
 		TEST_SLEEP_TIME, nb_steps, TEST_SLEEP_TIME_SHORT_STEP);
@@ -2443,7 +2561,7 @@ test_time ()
 	lw6sys_sleep (TEST_SLEEP_TIME_SHORT_STEP);
       }
     lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %" LW6SYS_PRINTF_LL "d ms"),
-		lw6sys_uptime () - last_uptime);
+		lw6sys_get_uptime () - last_uptime);
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -2544,6 +2662,8 @@ test_vthread ()
 /**
  * lw6sys_test
  *
+ * @mode: 0 for check only, 1 for full test
+ *
  * Runs the @sys module test suite, testing most (if not all...)
  * functions. Note that some tests perform file system operations
  * and might therefore fail on a read-only filesystem, or if
@@ -2552,7 +2672,7 @@ test_vthread ()
  * Return value: 1 if test is successfull, 0 on error.
  */
 int
-lw6sys_test ()
+lw6sys_test (int mode)
 {
   int ret = 0;
 
