@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -87,7 +87,10 @@ thread_callback (void *thread_handler)
 	       * Now the caller is supposed to set "can_join"
 	       * to allow this thread to actually finish.
 	       */
-	      lw6sys_sleep (_LW6SYS_THREAD_JOIN_SLEEP);
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _("waiting for can_join to be 1, thread id=%u"),
+			  th->id);
+	      lw6sys_idle ();
 	    }
 	  th->callback_join (th->callback_data);
 	}
