@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -104,9 +104,9 @@ typedef char *char_ptr_t;
 #include "../def/def.h"
 
 #ifdef LW6_PARANOID
-#define LW6SYS_BAZOOKA_DEFAULT_SIZE 1000000
+#define LW6SYS_BAZOOKA_DEFAULT_SIZE 999983
 #else
-#define LW6SYS_BAZOOKA_DEFAULT_SIZE 100000
+#define LW6SYS_BAZOOKA_DEFAULT_SIZE 99991
 #endif
 
 #define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_time_init(); lw6sys_history_init(); lw6sys_default_memory_bazooka(); lw6sys_profiler_check(1); }
@@ -233,6 +233,7 @@ typedef void (*lw6sys_assoc_callback_func_t) (void *func_data, char *key,
 typedef void (*lw6sys_list_callback_func_t) (void *func_data, void *data);
 typedef void *(*lw6sys_dup_func_t) (void *data);
 typedef void (*lw6sys_thread_callback_func_t) (void *callback_data);
+typedef int (*lw6sys_dir_list_filter_func_t) (void *func_data, char *file);
 
 typedef struct lw6sys_assoc_s
 {
@@ -332,6 +333,7 @@ extern int lw6sys_arg_exists (int argc, char *argv[], char *keyword);
 extern char *lw6sys_arg_get_value (int argc, char *argv[], char *keyword);
 extern char *lw6sys_arg_get_value_with_env (int argc, char *argv[],
 					    char *keyword);
+extern int lw6sys_arg_test_mode (int argc, char *argv[]);
 
 /* sys-assoc.c */
 extern lw6sys_assoc_t *lw6sys_assoc_new (lw6sys_free_func_t free_func);
@@ -361,6 +363,14 @@ extern int lw6sys_get_memory_bazooka_eraser ();
 extern int lw6sys_get_memory_bazooka_malloc_count ();
 extern int lw6sys_get_memory_bazooka_free_count ();
 extern int lw6sys_get_memory_bazooka_malloc_max ();
+extern int lw6sys_get_memory_bazooka_malloc_count ();
+extern int lw6sys_get_memory_bazooka_free_count ();
+extern int lw6sys_get_memory_bazooka_malloc_current_count ();
+extern int lw6sys_get_memory_bazooka_malloc_max_count ();
+extern int lw6sys_get_memory_bazooka_malloc_megabytes ();
+extern int lw6sys_get_memory_bazooka_free_megabytes ();
+extern int lw6sys_get_memory_bazooka_malloc_current_bytes ();
+extern int lw6sys_get_memory_bazooka_malloc_max_bytes ();
 extern int lw6sys_memory_bazooka_report ();
 
 /* sys-build.c */
@@ -373,6 +383,7 @@ extern char *lw6sys_build_get_stamp ();
 extern char *lw6sys_build_get_md5sum ();
 extern char *lw6sys_build_get_copyright ();
 extern char *lw6sys_build_get_license ();
+extern char *lw6sys_build_get_url ();
 extern char *lw6sys_build_get_configure_args ();
 extern char *lw6sys_build_get_gcc_version ();
 extern char *lw6sys_build_get_cflags ();
@@ -380,13 +391,14 @@ extern char *lw6sys_build_get_ldflags ();
 extern char *lw6sys_build_get_hostname ();
 extern char *lw6sys_build_get_date ();
 extern char *lw6sys_build_get_time ();
-extern char *lw6sys_build_get_target_cpu ();
+extern char *lw6sys_build_get_host_cpu ();
 extern char *lw6sys_build_get_endianness ();
 extern int lw6sys_build_get_pointer_size ();
 extern int lw6sys_build_is_x86 ();
-extern char *lw6sys_build_get_target_os ();
+extern char *lw6sys_build_get_host_os ();
 extern int lw6sys_build_is_ms_windows ();
 extern int lw6sys_build_is_mac_os_x ();
+extern int lw6sys_build_is_gp2x ();
 extern char *lw6sys_build_get_top_srcdir ();
 extern char *lw6sys_build_get_prefix ();
 extern char *lw6sys_build_get_datadir ();
@@ -408,6 +420,7 @@ extern char *lw6sys_build_get_enable_instrument ();
 extern char *lw6sys_build_get_enable_profiler ();
 extern char *lw6sys_build_get_enable_gcov ();
 extern char *lw6sys_build_get_enable_valgrind ();
+extern int lw6sys_build_get_bin_id ();
 extern void lw6sys_build_log_all ();
 
 /* sys-checksum.c */
@@ -447,6 +460,7 @@ extern void lw6sys_color_rgb_to_hsv (lw6sys_color_hsv_t * color_hsv,
 				     lw6sys_color_8_t color_8);
 extern lw6sys_color_8_t lw6sys_color_hsv_to_rgb (lw6sys_color_hsv_t *
 						 color_hsv);
+extern int lw6sys_color_is_grey (lw6sys_color_8_t color);
 extern lw6sys_color_8_t lw6sys_color_average (int size,
 					      lw6sys_color_8_t * colors);
 extern lw6sys_color_8_t lw6sys_color_ponderate (lw6sys_color_8_t color1,
@@ -676,6 +690,8 @@ extern char *lw6sys_get_default_log_file ();
 extern char *lw6sys_get_default_prefix ();
 extern char *lw6sys_get_default_mod_dir ();
 extern char *lw6sys_get_default_data_dir ();
+extern char *lw6sys_get_default_music_dir ();
+extern char *lw6sys_get_default_music_path ();
 extern char *lw6sys_get_default_map_dir ();
 extern char *lw6sys_get_default_map_path ();
 extern char *lw6sys_get_default_script_file ();
@@ -687,6 +703,8 @@ extern char *lw6sys_get_log_file (int argc, char *argv[]);
 extern char *lw6sys_get_prefix (int argc, char *argv[]);
 extern char *lw6sys_get_mod_dir (int argc, char *argv[]);
 extern char *lw6sys_get_data_dir (int argc, char *argv[]);
+extern char *lw6sys_get_music_dir (int argc, char *argv[]);
+extern char *lw6sys_get_music_path (int argc, char *argv[]);
 extern char *lw6sys_get_map_dir (int argc, char *argv[]);
 extern char *lw6sys_get_map_path (int argc, char *argv[]);
 extern char *lw6sys_get_script_file (int argc, char *argv[]);
@@ -706,6 +724,13 @@ extern int lw6sys_path_is_cwd (char *path);
 extern char *lw6sys_path_parent (char *path);
 extern char *lw6sys_path_unparent (char *path);
 extern char *lw6sys_path_unparent_no_malloc (char *path);
+extern lw6sys_list_t *lw6sys_dir_list (char *dir,
+				       lw6sys_dir_list_filter_func_t
+				       filter_func, void *func_data, int *n);
+extern lw6sys_list_t *lw6sys_path_list (char *path,
+					lw6sys_dir_list_filter_func_t
+					filter_func, void *func_data, int *n);
+extern char *lw6sys_find_in_dir_and_path (char *dir, char *path, char *file);
 
 /* sys-print.c */
 extern void lw6sys_print_xml_header (FILE * f, char *comment);
@@ -719,6 +744,10 @@ extern void lw6sys_progress_update (lw6sys_progress_t * progress, int min,
 extern void lw6sys_progress_split (lw6sys_progress_t * progress1,
 				   lw6sys_progress_t * progress2,
 				   lw6sys_progress_t * progress_src);
+extern void lw6sys_progress_split_here (lw6sys_progress_t * progress1,
+					lw6sys_progress_t * progress2,
+					lw6sys_progress_t * progress_src,
+					float here);
 extern void lw6sys_progress_split3 (lw6sys_progress_t * progress1,
 				    lw6sys_progress_t * progress2,
 				    lw6sys_progress_t * progress3,
@@ -760,6 +789,8 @@ extern int lw6sys_shape_check_min_max_whd (lw6sys_whd_t * shape, int min_wh,
 extern int lw6sys_shape_check_pos (lw6sys_whd_t * shape, lw6sys_xyz_t * pos);
 extern int lw6sys_shape_is_same (lw6sys_whd_t * shape_a,
 				 lw6sys_whd_t * shape_b);
+extern int lw6sys_shape_is_same_xy (lw6sys_whd_t * shape_a,
+				    lw6sys_whd_t * shape_b);
 
 /* sys-sort.c */
 extern int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
@@ -796,9 +827,12 @@ extern char *lw6sys_str_reformat (char *str, char *prefix, int nb_columns);
 extern char *lw6sys_eol ();
 extern lw6sys_list_t *lw6sys_str_split (char *str, char c);
 extern lw6sys_list_t *lw6sys_str_split_no_0 (char *str, char c);
+extern lw6sys_list_t *lw6sys_str_split_config_item (char *str);
+extern void lw6sys_str_toupper (char *str);
+extern void lw6sys_str_tolower (char *str);
 
 /* sys-test.c */
-extern int lw6sys_test ();
+extern int lw6sys_test (int mode);
 
 /* sys-testandset.s */
 extern int lw6sys_test_and_set (int *spinlock);
@@ -817,9 +851,11 @@ extern int lw6sys_get_thread_join_count ();
 extern int lw6sys_check_thread_count ();
 
 /* sys-time.c */
-extern int64_t lw6sys_timestamp ();
-extern int64_t lw6sys_uptime ();
-extern void lw6sys_timer_update (int64_t * timestamp, int64_t * uptime);
+extern int64_t lw6sys_get_timestamp ();
+extern int64_t lw6sys_get_uptime ();
+extern int32_t lw6sys_get_cycle ();
+extern void lw6sys_timer_update (int64_t * timestamp, int64_t * uptime,
+				 int32_t * cycle);
 extern void lw6sys_sleep (float seconds);
 extern void lw6sys_delay (int msec);
 extern void lw6sys_idle ();
